import unittest
from dfttopif.parsers.pwscf import PwscfParser
from ..test_pif import unpack_example, delete_example
from pypif.obj.common.value import Value
import os
import shutil

class TestPWSCFParser(unittest.TestCase):
        
    def get_parser(self,name):
        '''Get a PwscfParser for a certain test'''
        unpack_example(os.path.join('examples', 'pwscf', name+'.tar.gz'))
        return PwscfParser(name)

    def test_NaF(self):
        # Parse the results
        parser = self.get_parser('NaF.scf')
        
        # Test the settings
        self.assertEquals('PWSCF', parser.get_name())

        strc = parser.get_output_structure()
        self.assertEquals(2.2713025676424632, strc.cell[0][2])
        self.assertEquals(['F', 'Na'], strc.get_chemical_symbols())
        self.assertEquals('FNa', parser.get_composition())
        
        cutoff = parser.get_cutoff_energy()
        self.assertEquals(50.0, cutoff.scalars[0].value)
        self.assertEquals('Ry', cutoff.units)
        
        self.assertTrue(parser.is_converged().scalars[0].value)

        energy = parser.get_total_energy()
        self.assertEquals(-143.96084355, energy.scalars[0].value)
        self.assertEquals('Ry', energy.units)

        self.assertEquals(None, parser.uses_SOC())
        self.assertEquals(None, parser.is_relaxed())
        self.assertEquals('SLA PW PBE PBE', parser.get_xc_functional().scalars[0].value)
        self.assertEquals(['f_pbe_v1.4.uspp.F.UPF','Na_pbe_v1.uspp.F.UPF'], list(map(lambda x: x.value, parser.get_pp_name().scalars)))
        self.assertEquals(3456, parser.get_KPPRA().scalars[0].value)
        self.assertEquals('5.4.0', parser.get_version_number())
        self.assertEquals(None, parser.get_U_settings())
        self.assertEquals(None, parser.get_vdW_settings())
        self.assertEquals(None, parser.get_pressure())
        self.assertEquals(None, parser.get_stresses())
        self.assertEquals(None, parser.get_band_gap())
        self.assertEquals(None, parser.get_dos())
   
        # Delete the data
        delete_example('NaF.scf')
        
    def test_TiO2(self):
        # Parse the results
        parser = self.get_parser('TiO2.vcrelax')
        
        # Test the settings
        self.assertEquals('PWSCF', parser.get_name())

        strc = parser.get_output_structure()
        self.assertEquals(3.7373367889445048, strc.cell[0][0])
        self.assertEquals(['Ti', 'Ti', 'Ti', 'Ti', 'O', 'O', 'O', 'O', 'O', 'O', 'O', 'O'], strc.get_chemical_symbols())
        self.assertEquals('O8Ti4', parser.get_composition())
        
        cutoff = parser.get_cutoff_energy()
        self.assertEquals(50.0, cutoff.scalars[0].value)
        self.assertEquals('Ry', cutoff.units)

        self.assertTrue(parser.is_converged().scalars[0].value)

        energy = parser.get_total_energy()
        self.assertAlmostEqual(-724.67999404, energy.scalars[0].value)
        self.assertEquals('Ry', energy.units)

        self.assertEquals(None, parser.uses_SOC())
        self.assertTrue(isinstance(parser.is_relaxed(), Value))
        self.assertEquals('SLA PZ NOGX NOGC', parser.get_xc_functional().scalars[0].value)
        self.assertEquals(['Ti.pz-sp-van_ak.UPF', 'O.pz-van_ak.UPF'], list(map(lambda x: x.value, parser.get_pp_name().scalars)))
        self.assertEquals(4800, parser.get_KPPRA().scalars[0].value)
        self.assertEquals('4.3.2', parser.get_version_number())
        self.assertEquals(None, parser.get_U_settings())
        self.assertEquals(None, parser.get_vdW_settings())

        pressure = parser.get_pressure()
        self.assertEquals(-77.72, pressure.scalars[0].value)
        self.assertEquals('kbar', pressure.units)

        stresses = parser.get_stresses()
        self.assertEquals([[-2.32, 0.0, 0.0], [0.0, -2.32, 0.0], [0.0, 0.0, -2.36]],
                          list(map(lambda x: list(map(lambda y: y.value, x)), stresses.matrices[0])))
        self.assertEquals('kbar', stresses.units)

        self.assertEquals(None, parser.get_band_gap())

        # Delete the data
        delete_example('TiO2.vcrelax')
        
    def test_VS2(self):
        # Parse the results
        parser = self.get_parser('VS2.scf')
        
        # Test the settings
        self.assertEquals('PWSCF', parser.get_name())

        strc = parser.get_output_structure()
        self.assertEquals(1.5862881841690908, strc.cell[0][0])
        self.assertEquals(2.7475322138658069, strc.cell[1][1])
        self.assertEquals(39.999449897411992, strc.cell[2][2])
        self.assertEquals(['V', 'S', 'S'], strc.get_chemical_symbols())
        self.assertEquals('S2V', parser.get_composition())
        
        cutoff = parser.get_cutoff_energy()
        self.assertEquals(56.0, cutoff.scalars[0].value)
        self.assertEquals('Ry', cutoff.units)
        
        self.assertTrue(parser.is_converged().scalars[0].value)
        
        energy = parser.get_total_energy()
        self.assertEquals(-68.80612326, energy.scalars[0].value)
        self.assertEquals('Ry', energy.units)

        self.assertEquals(None, parser.uses_SOC())
        self.assertEquals(None, parser.is_relaxed())
        self.assertEquals('SLA PW PBE PBE', parser.get_xc_functional().scalars[0].value)
        self.assertEquals(['V.pbe-n-van.UPF', 'S.pbe-van_bm.UPF'], list(map(lambda x: x.value, parser.get_pp_name().scalars)))
        self.assertEquals(768, parser.get_KPPRA().scalars[0].value)
        self.assertEquals('4.3.2', parser.get_version_number())
        self.assertEquals(None, parser.get_U_settings())
        self.assertEquals(None, parser.get_vdW_settings())
        self.assertEquals(None, parser.get_pressure())
        self.assertEquals(None, parser.get_stresses())
        self.assertEquals(0, parser.get_band_gap().scalars[0].value)

        dos = parser.get_dos()
        self.assertEquals([-14.3248, -14.3198, -14.314799999999998, -14.3098, -14.3048, -14.299800000000001, -14.294799999999999, -14.2898, -14.2848, -14.279799999999998, -14.274799999999999, -14.2698, -14.264800000000001, -14.259799999999998, -14.2548, -14.2498, -14.244799999999998, -14.239799999999999, -14.2348, -14.229800000000001, -14.224799999999998, -14.2198, -14.2148, -14.209800000000001, -14.204799999999999, -14.1998, -14.1948, -14.189799999999998, -14.1848, -14.1798, -14.174800000000001, -14.169799999999999, -14.1648, -14.1598, -14.154799999999998, -14.149799999999999, -14.1448, -14.139800000000001, -14.134799999999998, -14.1298, -14.1248, -14.119799999999998, -14.114799999999999, -14.1098, -14.104800000000001, -14.099799999999998, -14.0948, -14.0898, -14.084800000000001, -14.079799999999999, -14.0748, -14.0698, -14.064799999999998, -14.0598, -14.0548, -14.049800000000001, -14.044799999999999, -14.0398, -14.0348, -14.029799999999998, -14.024799999999999, -14.0198, -14.014800000000001, -14.009799999999998, -14.0048, -13.9998, -13.994799999999998, -13.989799999999999, -13.9848, -13.979800000000001, -13.974799999999998, -13.9698, -13.9648, -13.959800000000001, -13.954799999999999, -13.9498, -13.9448, -13.939799999999998, -13.9348, -13.9298, -13.924800000000001, -13.919799999999999, -13.9148, -13.9098, -13.904799999999998, -13.899799999999999, -13.8948, -13.889800000000001, -13.884799999999998, -13.8798, -13.8748, -13.869799999999998, -13.864799999999999, -13.8598, -13.854800000000001, -13.849799999999998, -13.8448, -13.8398, -13.834800000000001, -13.829799999999999, -13.8248, -13.8198, -13.814799999999998, -13.8098, -13.8048, -13.799800000000001, -13.794799999999999, -13.7898, -13.7848, -13.779799999999998, -13.774799999999999, -13.7698, -13.764800000000001, -13.759799999999998, -13.7548, -13.7498, -13.744799999999998, -13.739799999999999, -13.7348, -13.729800000000001, -13.724799999999998, -13.7198, -13.7148, -13.709800000000001, -13.704799999999999, -13.6998, -13.6948, -13.689799999999998, -13.6848, -13.6798, -13.674800000000001, -13.669799999999999, -13.6648, -13.6598, -13.654799999999998, -13.649799999999999, -13.6448, -13.639800000000001, -13.634799999999998, -13.6298, -13.6248, -13.619799999999998, -13.614799999999999, -13.6098, -13.604800000000001, -13.599799999999998, -13.5948, -13.5898, -13.584800000000001, -13.579799999999999, -13.5748, -13.5698, -13.564799999999998, -13.5598, -13.5548, -13.549800000000001, -13.544799999999999, -13.5398, -13.5348, -13.529799999999998, -13.524799999999999, -13.5198, -13.514800000000001, -13.509799999999998, -13.5048, -13.4998, -13.494799999999998, -13.489799999999999, -13.4848, -13.479800000000001, -13.474799999999998, -13.4698, -13.4648, -13.459800000000001, -13.454799999999999, -13.4498, -13.4448, -13.439799999999998, -13.4348, -13.4298, -13.424800000000001, -13.419799999999999, -13.4148, -13.4098, -13.404799999999998, -13.399799999999999, -13.3948, -13.389800000000001, -13.384799999999998, -13.3798, -13.3748, -13.369799999999998, -13.364799999999999, -13.3598, -13.354800000000001, -13.349799999999998, -13.3448, -13.3398, -13.334800000000001, -13.329799999999999, -13.3248, -13.3198, -13.314799999999998, -13.3098, -13.3048, -13.299800000000001, -13.294799999999999, -13.2898, -13.2848, -13.279799999999998, -13.274799999999999, -13.2698, -13.264800000000001, -13.259799999999998, -13.2548, -13.2498, -13.244799999999998, -13.239799999999999, -13.2348, -13.229800000000001, -13.224799999999998, -13.2198, -13.2148, -13.209800000000001, -13.204799999999999, -13.1998, -13.1948, -13.189799999999998, -13.1848, -13.1798, -13.174800000000001, -13.169799999999999, -13.1648, -13.1598, -13.154799999999998, -13.149799999999999, -13.1448, -13.139800000000001, -13.134799999999998, -13.1298, -13.1248, -13.119799999999998, -13.114799999999999, -13.1098, -13.104800000000001, -13.099799999999998, -13.0948, -13.0898, -13.084800000000001, -13.079799999999999, -13.0748, -13.0698, -13.064799999999998, -13.0598, -13.0548, -13.049800000000001, -13.044799999999999, -13.0398, -13.0348, -13.029799999999998, -13.024799999999999, -13.0198, -13.014800000000001, -13.009799999999998, -13.0048, -12.9998, -12.994799999999998, -12.989799999999999, -12.9848, -12.979800000000001, -12.974799999999998, -12.9698, -12.9648, -12.959800000000001, -12.954799999999999, -12.9498, -12.9448, -12.939799999999998, -12.9348, -12.9298, -12.924800000000001, -12.919799999999999, -12.9148, -12.9098, -12.904799999999998, -12.899799999999999, -12.8948, -12.889800000000001, -12.884799999999998, -12.8798, -12.8748, -12.869799999999998, -12.864799999999999, -12.8598, -12.854800000000001, -12.849799999999998, -12.8448, -12.8398, -12.834800000000001, -12.829799999999999, -12.8248, -12.8198, -12.814799999999998, -12.8098, -12.8048, -12.799800000000001, -12.794799999999999, -12.7898, -12.7848, -12.779799999999998, -12.774799999999999, -12.7698, -12.764800000000001, -12.759799999999998, -12.7548, -12.7498, -12.744799999999998, -12.739799999999999, -12.7348, -12.729800000000001, -12.724799999999998, -12.7198, -12.7148, -12.709800000000001, -12.704799999999999, -12.6998, -12.6948, -12.689799999999998, -12.6848, -12.6798, -12.674800000000001, -12.669799999999999, -12.6648, -12.6598, -12.654799999999998, -12.649799999999999, -12.6448, -12.639800000000001, -12.634799999999998, -12.6298, -12.6248, -12.619799999999998, -12.614799999999999, -12.6098, -12.604800000000001, -12.599799999999998, -12.5948, -12.5898, -12.584800000000001, -12.579799999999999, -12.5748, -12.5698, -12.564799999999998, -12.5598, -12.5548, -12.549800000000001, -12.544799999999999, -12.5398, -12.5348, -12.529799999999998, -12.524799999999999, -12.5198, -12.514800000000001, -12.509799999999998, -12.5048, -12.4998, -12.494799999999998, -12.489799999999999, -12.4848, -12.479800000000001, -12.474799999999998, -12.4698, -12.4648, -12.459800000000001, -12.454799999999999, -12.4498, -12.4448, -12.439799999999998, -12.4348, -12.4298, -12.424800000000001, -12.419799999999999, -12.4148, -12.4098, -12.404799999999998, -12.399799999999999, -12.3948, -12.389800000000001, -12.384799999999998, -12.3798, -12.3748, -12.369799999999998, -12.364799999999999, -12.3598, -12.354800000000001, -12.349799999999998, -12.3448, -12.3398, -12.334800000000001, -12.329799999999999, -12.3248, -12.3198, -12.314799999999998, -12.3098, -12.3048, -12.299800000000001, -12.294799999999999, -12.2898, -12.2848, -12.279799999999998, -12.274799999999999, -12.2698, -12.264800000000001, -12.259799999999998, -12.2548, -12.2498, -12.244799999999998, -12.239799999999999, -12.2348, -12.229800000000001, -12.224799999999998, -12.2198, -12.2148, -12.209800000000001, -12.204799999999999, -12.1998, -12.1948, -12.189799999999998, -12.1848, -12.1798, -12.174800000000001, -12.169799999999999, -12.1648, -12.1598, -12.154799999999998, -12.149799999999999, -12.1448, -12.139800000000001, -12.134799999999998, -12.1298, -12.1248, -12.119799999999998, -12.114799999999999, -12.1098, -12.104800000000001, -12.099799999999998, -12.0948, -12.0898, -12.084800000000001, -12.079799999999999, -12.0748, -12.0698, -12.064799999999998, -12.0598, -12.0548, -12.049800000000001, -12.044799999999999, -12.0398, -12.034799999999999, -12.0298, -12.024799999999999, -12.0198, -12.0148, -12.0098, -12.0048, -11.9998, -11.9948, -11.989799999999999, -11.9848, -11.9798, -11.9748, -11.9698, -11.9648, -11.9598, -11.954799999999999, -11.9498, -11.944799999999999, -11.9398, -11.9348, -11.9298, -11.9248, -11.9198, -11.9148, -11.909799999999999, -11.9048, -11.899799999999999, -11.8948, -11.8898, -11.8848, -11.8798, -11.8748, -11.8698, -11.864799999999999, -11.8598, -11.8548, -11.8498, -11.8448, -11.8398, -11.8348, -11.829799999999999, -11.8248, -11.819799999999999, -11.8148, -11.8098, -11.8048, -11.7998, -11.7948, -11.7898, -11.784799999999999, -11.7798, -11.774799999999999, -11.7698, -11.7648, -11.7598, -11.7548, -11.7498, -11.7448, -11.739799999999999, -11.7348, -11.7298, -11.7248, -11.7198, -11.7148, -11.7098, -11.704799999999999, -11.6998, -11.694799999999999, -11.6898, -11.6848, -11.6798, -11.6748, -11.6698, -11.6648, -11.659799999999999, -11.6548, -11.649799999999999, -11.6448, -11.6398, -11.6348, -11.6298, -11.6248, -11.6198, -11.614799999999999, -11.6098, -11.6048, -11.5998, -11.5948, -11.5898, -11.5848, -11.579799999999999, -11.5748, -11.569799999999999, -11.5648, -11.5598, -11.5548, -11.5498, -11.5448, -11.5398, -11.534799999999999, -11.5298, -11.524799999999999, -11.5198, -11.5148, -11.5098, -11.5048, -11.4998, -11.4948, -11.489799999999999, -11.4848, -11.4798, -11.4748, -11.4698, -11.4648, -11.4598, -11.454799999999999, -11.4498, -11.444799999999999, -11.4398, -11.4348, -11.4298, -11.4248, -11.4198, -11.4148, -11.409799999999999, -11.4048, -11.399799999999999, -11.3948, -11.3898, -11.3848, -11.3798, -11.3748, -11.3698, -11.364799999999999, -11.3598, -11.3548, -11.3498, -11.3448, -11.3398, -11.3348, -11.329799999999999, -11.3248, -11.319799999999999, -11.3148, -11.3098, -11.3048, -11.2998, -11.2948, -11.2898, -11.284799999999999, -11.2798, -11.274799999999999, -11.2698, -11.2648, -11.2598, -11.2548, -11.2498, -11.2448, -11.239799999999999, -11.2348, -11.2298, -11.2248, -11.2198, -11.2148, -11.2098, -11.204799999999999, -11.1998, -11.194799999999999, -11.1898, -11.1848, -11.1798, -11.1748, -11.1698, -11.1648, -11.159799999999999, -11.1548, -11.149799999999999, -11.1448, -11.1398, -11.1348, -11.1298, -11.1248, -11.1198, -11.114799999999999, -11.1098, -11.1048, -11.0998, -11.0948, -11.0898, -11.0848, -11.079799999999999, -11.0748, -11.069799999999999, -11.0648, -11.0598, -11.0548, -11.0498, -11.0448, -11.0398, -11.034799999999999, -11.0298, -11.024799999999999, -11.0198, -11.0148, -11.0098, -11.0048, -10.9998, -10.9948, -10.989799999999999, -10.9848, -10.9798, -10.9748, -10.9698, -10.9648, -10.9598, -10.954799999999999, -10.9498, -10.944799999999999, -10.9398, -10.9348, -10.9298, -10.9248, -10.9198, -10.9148, -10.909799999999999, -10.9048, -10.899799999999999, -10.8948, -10.8898, -10.8848, -10.8798, -10.8748, -10.8698, -10.864799999999999, -10.8598, -10.8548, -10.8498, -10.8448, -10.8398, -10.8348, -10.829799999999999, -10.8248, -10.819799999999999, -10.8148, -10.8098, -10.8048, -10.7998, -10.7948, -10.7898, -10.784799999999999, -10.7798, -10.774799999999999, -10.7698, -10.7648, -10.7598, -10.7548, -10.7498, -10.7448, -10.739799999999999, -10.7348, -10.7298, -10.7248, -10.7198, -10.7148, -10.7098, -10.704799999999999, -10.6998, -10.694799999999999, -10.6898, -10.6848, -10.6798, -10.6748, -10.6698, -10.6648, -10.659799999999999, -10.6548, -10.649799999999999, -10.6448, -10.6398, -10.6348, -10.6298, -10.6248, -10.6198, -10.614799999999999, -10.6098, -10.6048, -10.5998, -10.5948, -10.5898, -10.5848, -10.579799999999999, -10.5748, -10.569799999999999, -10.5648, -10.5598, -10.5548, -10.5498, -10.5448, -10.5398, -10.534799999999999, -10.5298, -10.524799999999999, -10.5198, -10.5148, -10.5098, -10.5048, -10.4998, -10.4948, -10.489799999999999, -10.4848, -10.4798, -10.4748, -10.4698, -10.4648, -10.4598, -10.454799999999999, -10.4498, -10.444799999999999, -10.4398, -10.4348, -10.4298, -10.4248, -10.4198, -10.4148, -10.409799999999999, -10.4048, -10.399799999999999, -10.3948, -10.3898, -10.3848, -10.3798, -10.3748, -10.3698, -10.364799999999999, -10.3598, -10.3548, -10.3498, -10.3448, -10.3398, -10.3348, -10.329799999999999, -10.3248, -10.319799999999999, -10.3148, -10.3098, -10.3048, -10.2998, -10.2948, -10.2898, -10.284799999999999, -10.2798, -10.274799999999999, -10.2698, -10.2648, -10.2598, -10.2548, -10.2498, -10.2448, -10.239799999999999, -10.2348, -10.2298, -10.2248, -10.2198, -10.2148, -10.2098, -10.204799999999999, -10.1998, -10.194799999999999, -10.1898, -10.1848, -10.1798, -10.1748, -10.1698, -10.1648, -10.159799999999999, -10.1548, -10.149799999999999, -10.1448, -10.1398, -10.1348, -10.1298, -10.1248, -10.1198, -10.114799999999999, -10.1098, -10.1048, -10.0998, -10.0948, -10.0898, -10.0848, -10.079799999999999, -10.0748, -10.069799999999999, -10.0648, -10.0598, -10.0548, -10.0498, -10.0448, -10.0398, -10.034799999999999, -10.0298, -10.024799999999999, -10.0198, -10.0148, -10.0098, -10.0048, -9.9998, -9.9948, -9.989799999999999, -9.9848, -9.9798, -9.9748, -9.9698, -9.9648, -9.9598, -9.954799999999999, -9.9498, -9.944799999999999, -9.9398, -9.9348, -9.9298, -9.9248, -9.9198, -9.9148, -9.909799999999999, -9.9048, -9.899799999999999, -9.8948, -9.8898, -9.8848, -9.8798, -9.8748, -9.8698, -9.864799999999999, -9.8598, -9.8548, -9.8498, -9.8448, -9.8398, -9.8348, -9.829799999999999, -9.8248, -9.819799999999999, -9.8148, -9.8098, -9.8048, -9.7998, -9.7948, -9.7898, -9.784799999999999, -9.7798, -9.774799999999999, -9.7698, -9.7648, -9.7598, -9.7548, -9.7498, -9.7448, -9.739799999999999, -9.7348, -9.7298, -9.7248, -9.7198, -9.7148, -9.7098, -9.704799999999999, -9.6998, -9.694799999999999, -9.6898, -9.6848, -9.6798, -9.6748, -9.6698, -9.6648, -9.659799999999999, -9.6548, -9.649799999999999, -9.6448, -9.6398, -9.6348, -9.6298, -9.6248, -9.6198, -9.614799999999999, -9.6098, -9.6048, -9.5998, -9.5948, -9.5898, -9.5848, -9.579799999999999, -9.5748, -9.569799999999999, -9.5648, -9.5598, -9.5548, -9.5498, -9.5448, -9.5398, -9.534799999999999, -9.5298, -9.524799999999999, -9.5198, -9.5148, -9.5098, -9.5048, -9.4998, -9.4948, -9.489799999999999, -9.4848, -9.4798, -9.4748, -9.4698, -9.4648, -9.4598, -9.454799999999999, -9.4498, -9.444799999999999, -9.4398, -9.4348, -9.4298, -9.4248, -9.4198, -9.4148, -9.409799999999999, -9.4048, -9.399799999999999, -9.3948, -9.3898, -9.3848, -9.3798, -9.3748, -9.3698, -9.364799999999999, -9.3598, -9.3548, -9.3498, -9.3448, -9.3398, -9.3348, -9.329799999999999, -9.3248, -9.319799999999999, -9.3148, -9.3098, -9.3048, -9.2998, -9.2948, -9.2898, -9.284799999999999, -9.2798, -9.274799999999999, -9.2698, -9.2648, -9.2598, -9.2548, -9.2498, -9.2448, -9.239799999999999, -9.2348, -9.2298, -9.2248, -9.2198, -9.2148, -9.2098, -9.204799999999999, -9.1998, -9.194799999999999, -9.1898, -9.1848, -9.1798, -9.1748, -9.1698, -9.1648, -9.159799999999999, -9.1548, -9.149799999999999, -9.1448, -9.1398, -9.1348, -9.1298, -9.1248, -9.1198, -9.114799999999999, -9.1098, -9.1048, -9.0998, -9.0948, -9.0898, -9.0848, -9.079799999999999, -9.0748, -9.069799999999999, -9.0648, -9.0598, -9.0548, -9.0498, -9.0448, -9.0398, -9.034799999999999, -9.0298, -9.024799999999999, -9.0198, -9.0148, -9.0098, -9.0048, -8.9998, -8.9948, -8.989799999999999, -8.9848, -8.9798, -8.9748, -8.9698, -8.9648, -8.9598, -8.954799999999999, -8.9498, -8.944799999999999, -8.9398, -8.9348, -8.9298, -8.9248, -8.9198, -8.9148, -8.909799999999999, -8.9048, -8.899799999999999, -8.8948, -8.8898, -8.8848, -8.8798, -8.8748, -8.8698, -8.864799999999999, -8.8598, -8.8548, -8.8498, -8.8448, -8.8398, -8.8348, -8.829799999999999, -8.8248, -8.819799999999999, -8.8148, -8.8098, -8.8048, -8.7998, -8.7948, -8.7898, -8.784799999999999, -8.7798, -8.774799999999999, -8.7698, -8.7648, -8.7598, -8.7548, -8.7498, -8.7448, -8.739799999999999, -8.7348, -8.7298, -8.7248, -8.7198, -8.7148, -8.7098, -8.704799999999999, -8.6998, -8.694799999999999, -8.6898, -8.6848, -8.6798, -8.6748, -8.6698, -8.6648, -8.659799999999999, -8.6548, -8.649799999999999, -8.6448, -8.6398, -8.6348, -8.6298, -8.6248, -8.6198, -8.614799999999999, -8.6098, -8.6048, -8.5998, -8.5948, -8.5898, -8.5848, -8.579799999999999, -8.5748, -8.569799999999999, -8.5648, -8.5598, -8.5548, -8.5498, -8.5448, -8.5398, -8.534799999999999, -8.5298, -8.524799999999999, -8.5198, -8.5148, -8.5098, -8.5048, -8.4998, -8.4948, -8.489799999999999, -8.4848, -8.4798, -8.4748, -8.4698, -8.4648, -8.4598, -8.454799999999999, -8.4498, -8.444799999999999, -8.4398, -8.4348, -8.4298, -8.4248, -8.4198, -8.4148, -8.409799999999999, -8.4048, -8.399799999999999, -8.3948, -8.3898, -8.3848, -8.3798, -8.3748, -8.3698, -8.364799999999999, -8.3598, -8.3548, -8.3498, -8.3448, -8.3398, -8.3348, -8.329799999999999, -8.3248, -8.319799999999999, -8.3148, -8.3098, -8.3048, -8.2998, -8.2948, -8.2898, -8.284799999999999, -8.2798, -8.274799999999999, -8.2698, -8.2648, -8.2598, -8.2548, -8.2498, -8.2448, -8.239799999999999, -8.2348, -8.2298, -8.2248, -8.2198, -8.2148, -8.2098, -8.204799999999999, -8.1998, -8.194799999999999, -8.1898, -8.1848, -8.1798, -8.1748, -8.1698, -8.1648, -8.159799999999999, -8.1548, -8.149799999999999, -8.1448, -8.1398, -8.1348, -8.1298, -8.1248, -8.1198, -8.114799999999999, -8.1098, -8.1048, -8.0998, -8.0948, -8.0898, -8.0848, -8.079799999999999, -8.0748, -8.069799999999999, -8.0648, -8.0598, -8.0548, -8.0498, -8.0448, -8.0398, -8.034799999999999, -8.0298, -8.024799999999999, -8.0198, -8.0148, -8.0098, -8.0048, -7.9998000000000005, -7.9948, -7.989799999999999, -7.9848, -7.979799999999999, -7.9748, -7.969799999999999, -7.9648, -7.9597999999999995, -7.954799999999999, -7.9498, -7.944799999999999, -7.9398, -7.934799999999999, -7.9298, -7.924799999999999, -7.9198, -7.9148, -7.909799999999999, -7.9048, -7.899799999999999, -7.8948, -7.889799999999999, -7.8848, -7.8797999999999995, -7.8748000000000005, -7.8698, -7.864799999999999, -7.8598, -7.854799999999999, -7.8498, -7.844799999999999, -7.8398, -7.8347999999999995, -7.829799999999999, -7.8248, -7.819799999999999, -7.8148, -7.809799999999999, -7.8048, -7.799799999999999, -7.7948, -7.7898, -7.784799999999999, -7.7798, -7.774799999999999, -7.7698, -7.764799999999999, -7.7598, -7.7547999999999995, -7.7498000000000005, -7.7448, -7.739799999999999, -7.7348, -7.729799999999999, -7.7248, -7.719799999999999, -7.7148, -7.7097999999999995, -7.704799999999999, -7.6998, -7.694799999999999, -7.6898, -7.684799999999999, -7.6798, -7.674799999999999, -7.6698, -7.6648, -7.659799999999999, -7.6548, -7.649799999999999, -7.6448, -7.639799999999999, -7.6348, -7.6297999999999995, -7.6248000000000005, -7.6198, -7.614799999999999, -7.6098, -7.604799999999999, -7.5998, -7.594799999999999, -7.5898, -7.5847999999999995, -7.579799999999999, -7.5748, -7.569799999999999, -7.5648, -7.559799999999999, -7.5548, -7.549799999999999, -7.5448, -7.5398, -7.534799999999999, -7.5298, -7.524799999999999, -7.5198, -7.514799999999999, -7.5098, -7.5047999999999995, -7.4998000000000005, -7.4948, -7.489799999999999, -7.4848, -7.479799999999999, -7.4748, -7.469799999999999, -7.4648, -7.4597999999999995, -7.454799999999999, -7.4498, -7.444799999999999, -7.4398, -7.434799999999999, -7.4298, -7.424799999999999, -7.4198, -7.4148, -7.409799999999999, -7.4048, -7.399799999999999, -7.3948, -7.389799999999999, -7.3848, -7.3797999999999995, -7.3748000000000005, -7.3698, -7.364799999999999, -7.3598, -7.354799999999999, -7.3498, -7.344799999999999, -7.3398, -7.3347999999999995, -7.329799999999999, -7.3248, -7.319799999999999, -7.3148, -7.309799999999999, -7.3048, -7.299799999999999, -7.2948, -7.2898, -7.284799999999999, -7.2798, -7.274799999999999, -7.2698, -7.264799999999999, -7.2598, -7.2547999999999995, -7.2498000000000005, -7.2448, -7.239799999999999, -7.2348, -7.229799999999999, -7.2248, -7.219799999999999, -7.2148, -7.2097999999999995, -7.204799999999999, -7.1998, -7.194799999999999, -7.1898, -7.184799999999999, -7.1798, -7.174799999999999, -7.1698, -7.1648, -7.159799999999999, -7.1548, -7.149799999999999, -7.1448, -7.139799999999999, -7.1348, -7.1297999999999995, -7.1248000000000005, -7.1198, -7.114799999999999, -7.1098, -7.104799999999999, -7.0998, -7.094799999999999, -7.0898, -7.0847999999999995, -7.079799999999999, -7.0748, -7.069799999999999, -7.0648, -7.059799999999999, -7.0548, -7.049799999999999, -7.0448, -7.0398, -7.034799999999999, -7.0298, -7.024799999999999, -7.0198, -7.014799999999999, -7.0098, -7.0047999999999995, -6.9998000000000005, -6.9948, -6.989799999999999, -6.9848, -6.979799999999999, -6.9748, -6.969799999999999, -6.9648, -6.9597999999999995, -6.954799999999999, -6.9498, -6.944799999999999, -6.9398, -6.934799999999999, -6.9298, -6.924799999999999, -6.9198, -6.9148, -6.909799999999999, -6.9048, -6.899799999999999, -6.8948, -6.889799999999999, -6.8848, -6.8797999999999995, -6.8748000000000005, -6.8698, -6.864799999999999, -6.8598, -6.854799999999999, -6.8498, -6.844799999999999, -6.8398, -6.8347999999999995, -6.829799999999999, -6.8248, -6.819799999999999, -6.8148, -6.809799999999999, -6.8048, -6.799799999999999, -6.7948, -6.7898, -6.784799999999999, -6.7798, -6.774799999999999, -6.7698, -6.764799999999999, -6.7598, -6.7547999999999995, -6.7498000000000005, -6.7448, -6.739799999999999, -6.7348, -6.729799999999999, -6.7248, -6.719799999999999, -6.7148, -6.7097999999999995, -6.704799999999999, -6.6998, -6.694799999999999, -6.6898, -6.684799999999999, -6.6798, -6.674799999999999, -6.6698, -6.6648, -6.659799999999999, -6.6548, -6.649799999999999, -6.6448, -6.639799999999999, -6.6348, -6.6297999999999995, -6.6248000000000005, -6.6198, -6.614799999999999, -6.6098, -6.604799999999999, -6.5998, -6.594799999999999, -6.5898, -6.5847999999999995, -6.579799999999999, -6.5748, -6.569799999999999, -6.5648, -6.559799999999999, -6.5548, -6.549799999999999, -6.5448, -6.5398, -6.534799999999999, -6.5298, -6.524799999999999, -6.5198, -6.514799999999999, -6.5098, -6.5047999999999995, -6.4998000000000005, -6.4948, -6.489799999999999, -6.4848, -6.479799999999999, -6.4748, -6.469799999999999, -6.4648, -6.4597999999999995, -6.454799999999999, -6.4498, -6.444799999999999, -6.4398, -6.434799999999999, -6.4298, -6.424799999999999, -6.4198, -6.4148, -6.409799999999999, -6.4048, -6.399799999999999, -6.3948, -6.389799999999999, -6.3848, -6.3797999999999995, -6.3748000000000005, -6.3698, -6.364799999999999, -6.3598, -6.354799999999999, -6.3498, -6.344799999999999, -6.3398, -6.3347999999999995, -6.329799999999999, -6.3248, -6.319799999999999, -6.3148, -6.309799999999999, -6.3048, -6.299799999999999, -6.2948, -6.2898, -6.284799999999999, -6.2798, -6.274799999999999, -6.2698, -6.264799999999999, -6.2598, -6.2547999999999995, -6.2498000000000005, -6.2448, -6.239799999999999, -6.2348, -6.229799999999999, -6.2248, -6.219799999999999, -6.2148, -6.2097999999999995, -6.204799999999999, -6.1998, -6.194799999999999, -6.1898, -6.184799999999999, -6.1798, -6.174799999999999, -6.1698, -6.1648, -6.159799999999999, -6.1548, -6.149799999999999, -6.1448, -6.139799999999999, -6.1348, -6.1297999999999995, -6.1248000000000005, -6.1198, -6.114799999999999, -6.1098, -6.104799999999999, -6.0998, -6.094799999999999, -6.0898, -6.0847999999999995, -6.079799999999999, -6.0748, -6.069799999999999, -6.0648, -6.059799999999999, -6.0548, -6.049799999999999, -6.0448, -6.0398, -6.034799999999999, -6.0298, -6.024799999999999, -6.0198, -6.014799999999999, -6.0098, -6.0047999999999995, -5.9998000000000005, -5.9948, -5.989799999999999, -5.9848, -5.979799999999999, -5.9748, -5.969799999999999, -5.9648, -5.9597999999999995, -5.954799999999999, -5.9498, -5.944799999999999, -5.9398, -5.934799999999999, -5.9298, -5.924799999999999, -5.9198, -5.9148, -5.909799999999999, -5.9048, -5.899799999999999, -5.8948, -5.889799999999999, -5.8848, -5.8797999999999995, -5.8748000000000005, -5.8698, -5.864799999999999, -5.8598, -5.854799999999999, -5.8498, -5.844799999999999, -5.8398, -5.8347999999999995, -5.829799999999999, -5.8248, -5.819799999999999, -5.8148, -5.809799999999999, -5.8048, -5.799799999999999, -5.7948, -5.7898, -5.784799999999999, -5.7798, -5.774799999999999, -5.7698, -5.764799999999999, -5.7598, -5.7547999999999995, -5.7498000000000005, -5.7448, -5.739799999999999, -5.7348, -5.729799999999999, -5.7248, -5.719799999999999, -5.7148, -5.7097999999999995, -5.704799999999999, -5.6998, -5.694799999999999, -5.6898, -5.684799999999999, -5.6798, -5.674799999999999, -5.6698, -5.6648, -5.659799999999999, -5.6548, -5.649799999999999, -5.6448, -5.639799999999999, -5.6348, -5.6297999999999995, -5.6248000000000005, -5.6198, -5.614799999999999, -5.6098, -5.604799999999999, -5.5998, -5.594799999999999, -5.5898, -5.5847999999999995, -5.579799999999999, -5.5748, -5.569799999999999, -5.5648, -5.559799999999999, -5.5548, -5.549799999999999, -5.5448, -5.5398, -5.534799999999999, -5.5298, -5.524799999999999, -5.5198, -5.514799999999999, -5.5098, -5.5047999999999995, -5.4998000000000005, -5.4948, -5.489799999999999, -5.4848, -5.479799999999999, -5.4748, -5.469799999999999, -5.4648, -5.4597999999999995, -5.454799999999999, -5.4498, -5.444799999999999, -5.4398, -5.434799999999999, -5.4298, -5.424799999999999, -5.4198, -5.4148, -5.409799999999999, -5.4048, -5.399799999999999, -5.3948, -5.389799999999999, -5.3848, -5.3797999999999995, -5.3748000000000005, -5.3698, -5.364799999999999, -5.3598, -5.354799999999999, -5.3498, -5.344799999999999, -5.3398, -5.3347999999999995, -5.329799999999999, -5.3248, -5.319799999999999, -5.3148, -5.309799999999999, -5.3048, -5.299799999999999, -5.2948, -5.2898, -5.284799999999999, -5.2798, -5.274799999999999, -5.2698, -5.264799999999999, -5.2598, -5.2547999999999995, -5.2498000000000005, -5.2448, -5.239799999999999, -5.2348, -5.229799999999999, -5.2248, -5.219799999999999, -5.2148, -5.2097999999999995, -5.204799999999999, -5.1998, -5.194799999999999, -5.1898, -5.184799999999999, -5.1798, -5.174799999999999, -5.1698, -5.1648, -5.159799999999999, -5.1548, -5.149799999999999, -5.1448, -5.139799999999999, -5.1348, -5.1297999999999995, -5.1248000000000005, -5.1198, -5.114799999999999, -5.1098, -5.104799999999999, -5.0998, -5.094799999999999, -5.0898, -5.0847999999999995, -5.079799999999999, -5.0748, -5.069799999999999, -5.0648, -5.059799999999999, -5.0548, -5.049799999999999, -5.0448, -5.0398, -5.034799999999999, -5.0298, -5.024799999999999, -5.0198, -5.014799999999999, -5.0098, -5.0047999999999995, -4.9998000000000005, -4.9948, -4.989799999999999, -4.9848, -4.979799999999999, -4.9748, -4.969799999999999, -4.9648, -4.9597999999999995, -4.954799999999999, -4.9498, -4.944799999999999, -4.9398, -4.934799999999999, -4.9298, -4.924799999999999, -4.9198, -4.9148, -4.909799999999999, -4.9048, -4.899799999999999, -4.8948, -4.889799999999999, -4.8848, -4.8797999999999995, -4.8748000000000005, -4.8698, -4.864799999999999, -4.8598, -4.854799999999999, -4.8498, -4.844799999999999, -4.8398, -4.8347999999999995, -4.829799999999999, -4.8248, -4.819799999999999, -4.8148, -4.809799999999999, -4.8048, -4.799799999999999, -4.7948, -4.7898, -4.784799999999999, -4.7798, -4.774799999999999, -4.7698, -4.764799999999999, -4.7598, -4.7547999999999995, -4.7498000000000005, -4.7448, -4.739799999999999, -4.7348, -4.729799999999999, -4.7248, -4.719799999999999, -4.7148, -4.7097999999999995, -4.704799999999999, -4.6998, -4.694799999999999, -4.6898, -4.684799999999999, -4.6798, -4.674799999999999, -4.6698, -4.6648, -4.659799999999999, -4.6548, -4.649799999999999, -4.6448, -4.639799999999999, -4.6348, -4.6297999999999995, -4.6248000000000005, -4.6198, -4.614799999999999, -4.6098, -4.604799999999999, -4.5998, -4.594799999999999, -4.5898, -4.5847999999999995, -4.579799999999999, -4.5748, -4.569799999999999, -4.5648, -4.559799999999999, -4.5548, -4.549799999999999, -4.5448, -4.5398, -4.534799999999999, -4.5298, -4.524799999999999, -4.5198, -4.514799999999999, -4.5098, -4.5047999999999995, -4.4998000000000005, -4.4948, -4.489799999999999, -4.4848, -4.479799999999999, -4.4748, -4.469799999999999, -4.4648, -4.4597999999999995, -4.454799999999999, -4.4498, -4.444799999999999, -4.4398, -4.434799999999999, -4.4298, -4.424799999999999, -4.4198, -4.4148, -4.409799999999999, -4.4048, -4.399799999999999, -4.3948, -4.389799999999999, -4.3848, -4.3797999999999995, -4.3748000000000005, -4.3698, -4.364799999999999, -4.3598, -4.354799999999999, -4.3498, -4.344799999999999, -4.3398, -4.3347999999999995, -4.329799999999999, -4.3248, -4.319799999999999, -4.3148, -4.309799999999999, -4.3048, -4.299799999999999, -4.2948, -4.2898, -4.284799999999999, -4.2798, -4.274799999999999, -4.2698, -4.264799999999999, -4.2598, -4.2547999999999995, -4.2498000000000005, -4.2448, -4.239799999999999, -4.2348, -4.229799999999999, -4.2248, -4.219799999999999, -4.2148, -4.2097999999999995, -4.204799999999999, -4.1998, -4.194799999999999, -4.1898, -4.184799999999999, -4.1798, -4.174799999999999, -4.1698, -4.1648, -4.159799999999999, -4.1548, -4.149799999999999, -4.1448, -4.139799999999999, -4.1348, -4.1297999999999995, -4.1248000000000005, -4.1198, -4.114799999999999, -4.1098, -4.104799999999999, -4.0998, -4.094799999999999, -4.0898, -4.0847999999999995, -4.079799999999999, -4.0748, -4.069799999999999, -4.0648, -4.059799999999999, -4.0548, -4.049799999999999, -4.0448, -4.0398, -4.034800000000001, -4.0298, -4.024800000000001, -4.0198, -4.014799999999999, -4.0098, -4.0047999999999995, -3.9998, -3.9948, -3.9898000000000002, -3.9848000000000003, -3.9798000000000004, -3.9747999999999997, -3.9697999999999998, -3.9648, -3.9598, -3.9548, -3.9498, -3.9448000000000003, -3.9398000000000004, -3.9347999999999996, -3.9297999999999997, -3.9248, -3.9198, -3.9148, -3.9098, -3.9048000000000003, -3.8998000000000004, -3.8948000000000005, -3.8897999999999997, -3.8848, -3.8798, -3.8748, -3.8698, -3.8648000000000002, -3.8598000000000003, -3.8548000000000004, -3.8497999999999997, -3.8447999999999998, -3.8398, -3.8348, -3.8298, -3.8248, -3.8198000000000003, -3.8148000000000004, -3.8097999999999996, -3.8047999999999997, -3.7998, -3.7948, -3.7898, -3.7848, -3.7798000000000003, -3.7748000000000004, -3.7698000000000005, -3.7647999999999997, -3.7598, -3.7548, -3.7498, -3.7448, -3.7398000000000002, -3.7348000000000003, -3.7298000000000004, -3.7247999999999997, -3.7197999999999998, -3.7148, -3.7098, -3.7048, -3.6998, -3.6948000000000003, -3.6898000000000004, -3.6847999999999996, -3.6797999999999997, -3.6748, -3.6698, -3.6648, -3.6598, -3.6548000000000003, -3.6498000000000004, -3.6448000000000005, -3.6397999999999997, -3.6348, -3.6298, -3.6248, -3.6198, -3.6148000000000002, -3.6098000000000003, -3.6048000000000004, -3.5997999999999997, -3.5947999999999998, -3.5898, -3.5848, -3.5798, -3.5748, -3.5698000000000003, -3.5648000000000004, -3.5597999999999996, -3.5547999999999997, -3.5498, -3.5448, -3.5398, -3.5348, -3.5298000000000003, -3.5248000000000004, -3.5198000000000005, -3.5147999999999997, -3.5098, -3.5048, -3.4998, -3.4948, -3.4898000000000002, -3.4848000000000003, -3.4798000000000004, -3.4747999999999997, -3.4697999999999998, -3.4648, -3.4598, -3.4548, -3.4498, -3.4448000000000003, -3.4398000000000004, -3.4347999999999996, -3.4297999999999997, -3.4248, -3.4198, -3.4148, -3.4098, -3.4048000000000003, -3.3998000000000004, -3.3948000000000005, -3.3897999999999997, -3.3848, -3.3798, -3.3748, -3.3698, -3.3648000000000002, -3.3598000000000003, -3.3548000000000004, -3.3497999999999997, -3.3447999999999998, -3.3398, -3.3348, -3.3298, -3.3248, -3.3198000000000003, -3.3148000000000004, -3.3097999999999996, -3.3047999999999997, -3.2998, -3.2948, -3.2898, -3.2848, -3.2798000000000003, -3.2748000000000004, -3.2698000000000005, -3.2647999999999997, -3.2598, -3.2548, -3.2498, -3.2448, -3.2398000000000002, -3.2348000000000003, -3.2298000000000004, -3.2247999999999997, -3.2197999999999998, -3.2148, -3.2098, -3.2048, -3.1998, -3.1948000000000003, -3.1898000000000004, -3.1847999999999996, -3.1797999999999997, -3.1748, -3.1698, -3.1648, -3.1598, -3.1548000000000003, -3.1498000000000004, -3.1448000000000005, -3.1397999999999997, -3.1348, -3.1298, -3.1248, -3.1198, -3.1148000000000002, -3.1098000000000003, -3.1048000000000004, -3.0997999999999997, -3.0947999999999998, -3.0898, -3.0848, -3.0798, -3.0748, -3.0698000000000003, -3.0648000000000004, -3.0597999999999996, -3.0547999999999997, -3.0498, -3.0448, -3.0398, -3.0348, -3.0298000000000003, -3.0248000000000004, -3.0198000000000005, -3.0147999999999997, -3.0098, -3.0048, -2.9998, -2.9948, -2.9898000000000002, -2.9848000000000003, -2.9798000000000004, -2.9747999999999997, -2.9697999999999998, -2.9648, -2.9598, -2.9548, -2.9498, -2.9448000000000003, -2.9398000000000004, -2.9347999999999996, -2.9297999999999997, -2.9248, -2.9198, -2.9148, -2.9098, -2.9048000000000003, -2.8998000000000004, -2.8948000000000005, -2.8897999999999997, -2.8848, -2.8798, -2.8748, -2.8698, -2.8648000000000002, -2.8598000000000003, -2.8548000000000004, -2.8497999999999997, -2.8447999999999998, -2.8398, -2.8348, -2.8298, -2.8248, -2.8198000000000003, -2.8148000000000004, -2.8097999999999996, -2.8047999999999997, -2.7998, -2.7948, -2.7898, -2.7848, -2.7798000000000003, -2.7748000000000004, -2.7698000000000005, -2.7647999999999997, -2.7598, -2.7548, -2.7498, -2.7448, -2.7398000000000002, -2.7348000000000003, -2.7298000000000004, -2.7247999999999997, -2.7197999999999998, -2.7148, -2.7098, -2.7048, -2.6998, -2.6948000000000003, -2.6898000000000004, -2.6847999999999996, -2.6797999999999997, -2.6748, -2.6698, -2.6648, -2.6598, -2.6548000000000003, -2.6498000000000004, -2.6448000000000005, -2.6397999999999997, -2.6348, -2.6298, -2.6248, -2.6198, -2.6148000000000002, -2.6098000000000003, -2.6048000000000004, -2.5997999999999997, -2.5947999999999998, -2.5898, -2.5848, -2.5798, -2.5748, -2.5698000000000003, -2.5648000000000004, -2.5597999999999996, -2.5547999999999997, -2.5498, -2.5448, -2.5398, -2.5348, -2.5298000000000003, -2.5248000000000004, -2.5198000000000005, -2.5147999999999997, -2.5098, -2.5048, -2.4998, -2.4948, -2.4898000000000002, -2.4848000000000003, -2.4798000000000004, -2.4747999999999997, -2.4697999999999998, -2.4648, -2.4598, -2.4548, -2.4498, -2.4448000000000003, -2.4398000000000004, -2.4347999999999996, -2.4297999999999997, -2.4248, -2.4198, -2.4148, -2.4098, -2.4048000000000003, -2.3998000000000004, -2.3948000000000005, -2.3897999999999997, -2.3848, -2.3798, -2.3748, -2.3698, -2.3648000000000002, -2.3598000000000003, -2.3548000000000004, -2.3497999999999997, -2.3447999999999998, -2.3398, -2.3348, -2.3298, -2.3248, -2.3198000000000003, -2.3148000000000004, -2.3097999999999996, -2.3047999999999997, -2.2998, -2.2948, -2.2898, -2.2848, -2.2798000000000003, -2.2748000000000004, -2.2698000000000005, -2.2647999999999997, -2.2598, -2.2548, -2.2498, -2.2448, -2.2398000000000002, -2.2348000000000003, -2.2298000000000004, -2.2247999999999997, -2.2197999999999998, -2.2148, -2.2098, -2.2048, -2.1998, -2.1948000000000003, -2.1898000000000004, -2.1847999999999996, -2.1797999999999997, -2.1748, -2.1698, -2.1648, -2.1598, -2.1548000000000003, -2.1498000000000004, -2.1448000000000005, -2.1397999999999997, -2.1348, -2.1298, -2.1248, -2.1198, -2.1148000000000002, -2.1098000000000003, -2.1048000000000004, -2.0997999999999997, -2.0947999999999998, -2.0898, -2.0848, -2.0798, -2.0748, -2.0698000000000003, -2.0648000000000004, -2.0597999999999996, -2.0547999999999997, -2.0498, -2.0448, -2.0398, -2.0348, -2.0298000000000003, -2.0248000000000004, -2.0198000000000005, -2.0147999999999997, -2.0098, -2.0048, -1.9998, -1.9948000000000001, -1.9898000000000002, -1.9848000000000003, -1.9798000000000004, -1.9747999999999997, -1.9697999999999998, -1.9647999999999999, -1.9598, -1.9548, -1.9498000000000002, -1.9448000000000003, -1.9398000000000004, -1.9347999999999996, -1.9297999999999997, -1.9247999999999998, -1.9198, -1.9148, -1.9098000000000002, -1.9048000000000003, -1.8998000000000004, -1.8948000000000005, -1.8897999999999997, -1.8847999999999998, -1.8798, -1.8748, -1.8698000000000001, -1.8648000000000002, -1.8598000000000003, -1.8548000000000004, -1.8497999999999997, -1.8447999999999998, -1.8397999999999999, -1.8348, -1.8298, -1.8248000000000002, -1.8198000000000003, -1.8148000000000004, -1.8097999999999996, -1.8047999999999997, -1.7997999999999998, -1.7948, -1.7898, -1.7848000000000002, -1.7798000000000003, -1.7748000000000004, -1.7698000000000005, -1.7647999999999997, -1.7597999999999998, -1.7548, -1.7498, -1.7448000000000001, -1.7398000000000002, -1.7348000000000003, -1.7298000000000004, -1.7247999999999997, -1.7197999999999998, -1.7147999999999999, -1.7098, -1.7048, -1.6998000000000002, -1.6948000000000003, -1.6898000000000004, -1.6847999999999996, -1.6797999999999997, -1.6747999999999998, -1.6698, -1.6648, -1.6598000000000002, -1.6548000000000003, -1.6498000000000004, -1.6448000000000005, -1.6397999999999997, -1.6347999999999998, -1.6298, -1.6248, -1.6198000000000001, -1.6148000000000002, -1.6098000000000003, -1.6048000000000004, -1.5997999999999997, -1.5947999999999998, -1.5897999999999999, -1.5848, -1.5798, -1.5748000000000002, -1.5698000000000003, -1.5648000000000004, -1.5597999999999996, -1.5547999999999997, -1.5497999999999998, -1.5448, -1.5398, -1.5348000000000002, -1.5298000000000003, -1.5248000000000004, -1.5198000000000005, -1.5147999999999997, -1.5097999999999998, -1.5048, -1.4998, -1.4948000000000001, -1.4898000000000002, -1.4848000000000003, -1.4798000000000004, -1.4747999999999997, -1.4697999999999998, -1.4647999999999999, -1.4598, -1.4548, -1.4498000000000002, -1.4448000000000003, -1.4398000000000004, -1.4347999999999996, -1.4297999999999997, -1.4247999999999998, -1.4198, -1.4148, -1.4098000000000002, -1.4048000000000003, -1.3998000000000004, -1.3948000000000005, -1.3897999999999997, -1.3847999999999998, -1.3798, -1.3748, -1.3698000000000001, -1.3648000000000002, -1.3598000000000003, -1.3548000000000004, -1.3497999999999997, -1.3447999999999998, -1.3397999999999999, -1.3348, -1.3298, -1.3248000000000002, -1.3198000000000003, -1.3148000000000004, -1.3097999999999996, -1.3047999999999997, -1.2997999999999998, -1.2948, -1.2898, -1.2848000000000002, -1.2798000000000003, -1.2748000000000004, -1.2698000000000005, -1.2647999999999997, -1.2597999999999998, -1.2548, -1.2498, -1.2448000000000001, -1.2398000000000002, -1.2348000000000003, -1.2298000000000004, -1.2247999999999997, -1.2197999999999998, -1.2147999999999999, -1.2098, -1.2048, -1.1998000000000002, -1.1948000000000003, -1.1898000000000004, -1.1847999999999996, -1.1797999999999997, -1.1747999999999998, -1.1698, -1.1648, -1.1598000000000002, -1.1548000000000003, -1.1498000000000004, -1.1448000000000005, -1.1397999999999997, -1.1347999999999998, -1.1298, -1.1248, -1.1198000000000001, -1.1148000000000002, -1.1098000000000003, -1.1048000000000004, -1.0997999999999997, -1.0947999999999998, -1.0897999999999999, -1.0848, -1.0798, -1.0748000000000002, -1.0698000000000003, -1.0648000000000004, -1.0597999999999996, -1.0547999999999997, -1.0497999999999998, -1.0448, -1.0398, -1.0348000000000002, -1.0298000000000003, -1.0248000000000004, -1.0198000000000005, -1.0147999999999997, -1.0097999999999998, -1.0048, -0.9998, -0.9948000000000001, -0.9898000000000002, -0.9848000000000003, -0.9798000000000004, -0.9747999999999997, -0.9697999999999998, -0.9647999999999999, -0.9598, -0.9548000000000001, -0.9498000000000002, -0.9448000000000003, -0.9398000000000004, -0.9347999999999996, -0.9297999999999997, -0.9247999999999998, -0.9198, -0.9148000000000001, -0.9098000000000002, -0.9048000000000003, -0.8998000000000004, -0.8948000000000005, -0.8897999999999997, -0.8847999999999998, -0.8797999999999999, -0.8748, -0.8698000000000001, -0.8648000000000002, -0.8598000000000003, -0.8548000000000004, -0.8497999999999997, -0.8447999999999998, -0.8397999999999999, -0.8348, -0.8298000000000001, -0.8248000000000002, -0.8198000000000003, -0.8148000000000004, -0.8097999999999996, -0.8047999999999997, -0.7997999999999998, -0.7948, -0.7898000000000001, -0.7848000000000002, -0.7798000000000003, -0.7748000000000004, -0.7698000000000005, -0.7647999999999997, -0.7597999999999998, -0.7547999999999999, -0.7498, -0.7448000000000001, -0.7398000000000002, -0.7348000000000003, -0.7298000000000004, -0.7247999999999997, -0.7197999999999998, -0.7147999999999999, -0.7098, -0.7048000000000001, -0.6998000000000002, -0.6948000000000003, -0.6898000000000004, -0.6847999999999996, -0.6797999999999997, -0.6747999999999998, -0.6698, -0.6648000000000001, -0.6598000000000002, -0.6548000000000003, -0.6498000000000004, -0.6448000000000005, -0.6397999999999997, -0.6347999999999998, -0.6297999999999999, -0.6248, -0.6198000000000001, -0.6148000000000002, -0.6098000000000003, -0.6048000000000004, -0.5997999999999997, -0.5947999999999998, -0.5897999999999999, -0.5848, -0.5798000000000001, -0.5748000000000002, -0.5698000000000003, -0.5648000000000004, -0.5597999999999996, -0.5547999999999997, -0.5497999999999998, -0.5448, -0.5398000000000001, -0.5348000000000002, -0.5298000000000003, -0.5248000000000004, -0.5198000000000005, -0.5147999999999997, -0.5097999999999998, -0.5047999999999999, -0.4998, -0.49480000000000013, -0.48980000000000024, -0.48480000000000034, -0.47980000000000045, -0.47479999999999967, -0.4697999999999998, -0.4647999999999999, -0.4598, -0.4548000000000001, -0.4498000000000002, -0.4448000000000003, -0.4398000000000004, -0.43479999999999963, -0.42979999999999974, -0.42479999999999984, -0.41979999999999995, -0.41480000000000006, -0.40980000000000016, -0.40480000000000027, -0.3998000000000004, -0.3948000000000005, -0.3897999999999997, -0.3847999999999998, -0.3797999999999999, -0.3748, -0.36980000000000013, -0.36480000000000024, -0.35980000000000034, -0.35480000000000045, -0.34979999999999967, -0.3447999999999998, -0.3397999999999999, -0.3348, -0.3298000000000001, -0.3248000000000002, -0.3198000000000003, -0.3148000000000004, -0.30979999999999963, -0.30479999999999974, -0.29979999999999984, -0.29479999999999995, -0.28980000000000006, -0.28480000000000016, -0.27980000000000027, -0.2748000000000004, -0.2698000000000005, -0.2647999999999997, -0.2597999999999998, -0.2547999999999999, -0.24980000000000002, -0.24480000000000013, -0.23980000000000024, -0.23480000000000034, -0.22980000000000045, -0.22479999999999967, -0.21979999999999977, -0.21479999999999988, -0.2098, -0.2048000000000001, -0.1998000000000002, -0.1948000000000003, -0.1898000000000004, -0.18479999999999963, -0.17979999999999974, -0.17479999999999984, -0.16979999999999995, -0.16480000000000006, -0.15980000000000016, -0.15480000000000027, -0.14980000000000038, -0.14480000000000048, -0.1397999999999997, -0.1347999999999998, -0.12979999999999992, -0.12480000000000002, -0.11980000000000013, -0.11480000000000024, -0.10980000000000034, -0.10480000000000045, -0.09979999999999967, -0.09479999999999977, -0.08979999999999988, -0.08479999999999999, -0.0798000000000001, -0.0748000000000002, -0.0698000000000003, -0.06480000000000041, -0.05979999999999963, -0.05479999999999974, -0.049799999999999844, -0.04479999999999995, -0.03980000000000006, -0.034800000000000164, -0.02980000000000027, -0.024799999999999933, -0.01980000000000004, -0.014800000000000146, -0.009800000000000253, -0.0047999999999999154, 0.00019999999999997797, 0.005199999999999871, 0.010199999999999765, 0.015200000000000102, 0.020199999999999996, 0.02519999999999989, 0.030199999999999783, 0.03520000000000012, 0.040200000000000014, 0.04519999999999991, 0.0501999999999998, 0.05520000000000014, 0.06020000000000003, 0.06519999999999992, 0.07019999999999982, 0.07520000000000016, 0.08020000000000005, 0.08519999999999994, 0.09019999999999984, 0.09519999999999973, 0.10020000000000007, 0.10519999999999996, 0.11019999999999985, 0.11519999999999975, 0.12020000000000008, 0.12519999999999998, 0.13019999999999987, 0.13519999999999976, 0.1402000000000001, 0.1452, 0.1501999999999999, 0.15519999999999978, 0.16020000000000012, 0.1652, 0.1701999999999999, 0.1751999999999998, 0.18020000000000014, 0.18520000000000003, 0.19019999999999992, 0.19519999999999982, 0.20020000000000016, 0.20520000000000005, 0.21019999999999994, 0.21519999999999984, 0.22019999999999973, 0.22520000000000007, 0.23019999999999996, 0.23519999999999985, 0.24019999999999975, 0.24520000000000008, 0.2502, 0.25519999999999987, 0.26019999999999976, 0.2652000000000001, 0.2702, 0.2751999999999999, 0.2801999999999998, 0.2852000000000001, 0.2902, 0.2951999999999999, 0.3001999999999998, 0.30520000000000014, 0.31020000000000003, 0.3151999999999999, 0.3201999999999998, 0.32520000000000016, 0.33020000000000005, 0.33519999999999994, 0.34019999999999984, 0.34519999999999973, 0.35020000000000007, 0.35519999999999996, 0.36019999999999985, 0.36519999999999975, 0.3702000000000001, 0.3752, 0.38019999999999987, 0.38519999999999976, 0.3902000000000001, 0.3952, 0.4001999999999999, 0.4051999999999998, 0.4102000000000001, 0.4152, 0.4201999999999999, 0.4251999999999998, 0.43020000000000014, 0.43520000000000003, 0.4401999999999999, 0.4451999999999998, 0.45020000000000016, 0.45520000000000005, 0.46019999999999994, 0.46519999999999984, 0.47019999999999973, 0.47520000000000007, 0.48019999999999996, 0.48519999999999985, 0.49019999999999975, 0.4952000000000001, 0.5002, 0.5051999999999999, 0.5101999999999998, 0.5152000000000001, 0.5202, 0.5251999999999999, 0.5301999999999998, 0.5352000000000001, 0.5402, 0.5451999999999999, 0.5501999999999998, 0.5552000000000001, 0.5602, 0.5651999999999999, 0.5701999999999998, 0.5752000000000002, 0.5802, 0.5851999999999999, 0.5901999999999998, 0.5951999999999997, 0.6002000000000001, 0.6052, 0.6101999999999999, 0.6151999999999997, 0.6202000000000001, 0.6252, 0.6301999999999999, 0.6351999999999998, 0.6402000000000001, 0.6452, 0.6501999999999999, 0.6551999999999998, 0.6602000000000001, 0.6652, 0.6701999999999999, 0.6751999999999998, 0.6802000000000001, 0.6852, 0.6901999999999999, 0.6951999999999998, 0.7002000000000002, 0.7052, 0.7101999999999999, 0.7151999999999998, 0.7201999999999997, 0.7252000000000001, 0.7302, 0.7351999999999999, 0.7401999999999997, 0.7452000000000001, 0.7502, 0.7551999999999999, 0.7601999999999998, 0.7652000000000001, 0.7702, 0.7751999999999999, 0.7801999999999998, 0.7852000000000001, 0.7902, 0.7951999999999999, 0.8001999999999998, 0.8052000000000001, 0.8102, 0.8151999999999999, 0.8201999999999998, 0.8252000000000002, 0.8302, 0.8351999999999999, 0.8401999999999998, 0.8451999999999997, 0.8502000000000001, 0.8552, 0.8601999999999999, 0.8651999999999997, 0.8702000000000001, 0.8752, 0.8801999999999999, 0.8851999999999998, 0.8902000000000001, 0.8952, 0.9001999999999999, 0.9051999999999998, 0.9102000000000001, 0.9152, 0.9201999999999999, 0.9251999999999998, 0.9302000000000001, 0.9352, 0.9401999999999999, 0.9451999999999998, 0.9502000000000002, 0.9552, 0.9601999999999999, 0.9651999999999998, 0.9701999999999997, 0.9752000000000001, 0.9802, 0.9851999999999999, 0.9901999999999997, 0.9952000000000001, 1.0002, 1.0051999999999999, 1.0101999999999998, 1.0152, 1.0202, 1.0252, 1.0301999999999998, 1.0352000000000001, 1.0402, 1.0452, 1.0501999999999998, 1.0552000000000001, 1.0602, 1.0652, 1.0701999999999998, 1.0752000000000002, 1.0802, 1.0852, 1.0901999999999998, 1.0951999999999997, 1.1002, 1.1052, 1.1101999999999999, 1.1151999999999997, 1.1202, 1.1252, 1.1301999999999999, 1.1351999999999998, 1.1402, 1.1452, 1.1502, 1.1551999999999998, 1.1602000000000001, 1.1652, 1.1702, 1.1751999999999998, 1.1802000000000001, 1.1852, 1.1902, 1.1951999999999998, 1.2002000000000002, 1.2052, 1.2102, 1.2151999999999998, 1.2201999999999997, 1.2252, 1.2302, 1.2351999999999999, 1.2401999999999997, 1.2452, 1.2502, 1.2551999999999999, 1.2601999999999998, 1.2652, 1.2702, 1.2752, 1.2801999999999998, 1.2852000000000001, 1.2902, 1.2952, 1.3001999999999998, 1.3052000000000001, 1.3102, 1.3152, 1.3201999999999998, 1.3252000000000002, 1.3302, 1.3352, 1.3401999999999998, 1.3451999999999997, 1.3502, 1.3552, 1.3601999999999999, 1.3651999999999997, 1.3702, 1.3752, 1.3801999999999999, 1.3851999999999998, 1.3902, 1.3952, 1.4002, 1.4051999999999998, 1.4102000000000001, 1.4152, 1.4202, 1.4251999999999998, 1.4302000000000001, 1.4352, 1.4402, 1.4451999999999998, 1.4502000000000002, 1.4552, 1.4602, 1.4651999999999998, 1.4701999999999997, 1.4752, 1.4802, 1.4851999999999999, 1.4901999999999997, 1.4952, 1.5002, 1.5051999999999999, 1.5101999999999998, 1.5152, 1.5202, 1.5252, 1.5301999999999998, 1.5352000000000001, 1.5402, 1.5452, 1.5501999999999998, 1.5552000000000001, 1.5602, 1.5652, 1.5701999999999998, 1.5752000000000002, 1.5802, 1.5852, 1.5901999999999998, 1.5951999999999997, 1.6002, 1.6052, 1.6101999999999999, 1.6151999999999997, 1.6202, 1.6252, 1.6301999999999999, 1.6351999999999998, 1.6402, 1.6452, 1.6502, 1.6551999999999998, 1.6602000000000001, 1.6652, 1.6702, 1.6751999999999998, 1.6802000000000001, 1.6852, 1.6902, 1.6951999999999998, 1.7002000000000002, 1.7052, 1.7102, 1.7151999999999998, 1.7201999999999997, 1.7252, 1.7302, 1.7351999999999999, 1.7401999999999997, 1.7452, 1.7502, 1.7551999999999999, 1.7601999999999998, 1.7652, 1.7702, 1.7752, 1.7801999999999998, 1.7852000000000001, 1.7902, 1.7952, 1.8001999999999998, 1.8052000000000001, 1.8102, 1.8152, 1.8201999999999998, 1.8252000000000002, 1.8302, 1.8352, 1.8401999999999998, 1.8451999999999997, 1.8502, 1.8552, 1.8601999999999999, 1.8651999999999997, 1.8702, 1.8752, 1.8801999999999999, 1.8851999999999998, 1.8902, 1.8952, 1.9002, 1.9051999999999998, 1.9102000000000001, 1.9152, 1.9202, 1.9251999999999998, 1.9302000000000001, 1.9352, 1.9402, 1.9451999999999998, 1.9502000000000002, 1.9552, 1.9602, 1.9651999999999998, 1.9702, 1.9751999999999998, 1.9802, 1.9851999999999999, 1.9902, 1.9951999999999999, 2.0002, 2.0052, 2.0102, 2.0152, 2.0202, 2.0252, 2.0302, 2.0351999999999997, 2.0402, 2.0452, 2.0502000000000002, 2.0552, 2.0602, 2.0652, 2.0702, 2.0751999999999997, 2.0802, 2.0852, 2.0902, 2.0952, 2.1002, 2.1052, 2.1102, 2.1151999999999997, 2.1201999999999996, 2.1252, 2.1302, 2.1352, 2.1402, 2.1452, 2.1502, 2.1552, 2.1601999999999997, 2.1652, 2.1702, 2.1752000000000002, 2.1802, 2.1852, 2.1902, 2.1952, 2.2001999999999997, 2.2052, 2.2102, 2.2152, 2.2202, 2.2252, 2.2302, 2.2352, 2.2401999999999997, 2.2451999999999996, 2.2502, 2.2552, 2.2602, 2.2652, 2.2702, 2.2752, 2.2802, 2.2851999999999997, 2.2902, 2.2952, 2.3002000000000002, 2.3052, 2.3102, 2.3152, 2.3202, 2.3251999999999997, 2.3302, 2.3352, 2.3402, 2.3452, 2.3502, 2.3552, 2.3602, 2.3651999999999997, 2.3701999999999996, 2.3752, 2.3802, 2.3852, 2.3902, 2.3952, 2.4002, 2.4052, 2.4101999999999997, 2.4152, 2.4202, 2.4252000000000002, 2.4302, 2.4352, 2.4402, 2.4452, 2.4501999999999997, 2.4552, 2.4602, 2.4652, 2.4702, 2.4752, 2.4802, 2.4852, 2.4901999999999997, 2.4951999999999996, 2.5002, 2.5052, 2.5102, 2.5152, 2.5202, 2.5252, 2.5302, 2.5351999999999997, 2.5402, 2.5452, 2.5502000000000002, 2.5552, 2.5602, 2.5652, 2.5702, 2.5751999999999997, 2.5802, 2.5852, 2.5902, 2.5952, 2.6002, 2.6052, 2.6102, 2.6151999999999997, 2.6201999999999996, 2.6252, 2.6302, 2.6352, 2.6402, 2.6452, 2.6502, 2.6552, 2.6601999999999997, 2.6652, 2.6702, 2.6752000000000002, 2.6802, 2.6852, 2.6902, 2.6952, 2.7001999999999997, 2.7052, 2.7102, 2.7152, 2.7202, 2.7252, 2.7302, 2.7352, 2.7401999999999997, 2.7451999999999996, 2.7502, 2.7552, 2.7602, 2.7652, 2.7702, 2.7752, 2.7802, 2.7851999999999997, 2.7902, 2.7952, 2.8002000000000002, 2.8052, 2.8102, 2.8152, 2.8202, 2.8251999999999997, 2.8302, 2.8352, 2.8402, 2.8452, 2.8502, 2.8552, 2.8602, 2.8651999999999997, 2.8701999999999996, 2.8752, 2.8802, 2.8852, 2.8902, 2.8952, 2.9002, 2.9052, 2.9101999999999997, 2.9152, 2.9202, 2.9252000000000002, 2.9302, 2.9352, 2.9402, 2.9452, 2.9501999999999997, 2.9552, 2.9602, 2.9652, 2.9702, 2.9752, 2.9802, 2.9852, 2.9901999999999997, 2.9952, 3.0002, 3.0052, 3.0102, 3.0152, 3.0202, 3.0252, 3.0302, 3.0351999999999997, 3.0402, 3.0452, 3.0502, 3.0552, 3.0602, 3.0652, 3.0702, 3.0751999999999997, 3.0802, 3.0852, 3.0902, 3.0952, 3.1002, 3.1052, 3.1102, 3.1151999999999997, 3.1202, 3.1252, 3.1302, 3.1352, 3.1402, 3.1452, 3.1502, 3.1552, 3.1601999999999997, 3.1652, 3.1702, 3.1752, 3.1802, 3.1852, 3.1902, 3.1952, 3.2001999999999997, 3.2052, 3.2102, 3.2152, 3.2202, 3.2252, 3.2302, 3.2352, 3.2401999999999997, 3.2452, 3.2502, 3.2552, 3.2602, 3.2652, 3.2702, 3.2752, 3.2802, 3.2851999999999997, 3.2902, 3.2952, 3.3002, 3.3052, 3.3102, 3.3152, 3.3202, 3.3251999999999997, 3.3302, 3.3352, 3.3402, 3.3452, 3.3502, 3.3552, 3.3602, 3.3651999999999997, 3.3702, 3.3752, 3.3802, 3.3852, 3.3902, 3.3952, 3.4002, 3.4052, 3.4101999999999997, 3.4152, 3.4202, 3.4252, 3.4302, 3.4352, 3.4402, 3.4452, 3.4501999999999997, 3.4552, 3.4602, 3.4652, 3.4702, 3.4752, 3.4802, 3.4852, 3.4901999999999997, 3.4952, 3.5002, 3.5052, 3.5101999999999998, 3.5152, 3.5202, 3.5252, 3.5302, 3.5352, 3.5402, 3.5452, 3.5502, 3.5552, 3.5602, 3.5652, 3.5702, 3.5751999999999997, 3.5802, 3.5852, 3.5902, 3.5952, 3.6002, 3.6052, 3.6102, 3.6151999999999997, 3.6202, 3.6252, 3.6302, 3.6351999999999998, 3.6402, 3.6452, 3.6502, 3.6552, 3.6602, 3.6652, 3.6702, 3.6752, 3.6802, 3.6852, 3.6902, 3.6952, 3.7001999999999997, 3.7052, 3.7102, 3.7152, 3.7202, 3.7252, 3.7302, 3.7352, 3.7401999999999997, 3.7452, 3.7502, 3.7552, 3.7601999999999998, 3.7652, 3.7702, 3.7752, 3.7802, 3.7852, 3.7902, 3.7952, 3.8002, 3.8052, 3.8102, 3.8152, 3.8202, 3.8251999999999997, 3.8302, 3.8352, 3.8402, 3.8451999999999997, 3.8502, 3.8552, 3.8602, 3.8651999999999997, 3.8702, 3.8752, 3.8802, 3.8851999999999998, 3.8902, 3.8952, 3.9002, 3.9052, 3.9102, 3.9152, 3.9202, 3.9252, 3.9302, 3.9352, 3.9402, 3.9452, 3.9502, 3.9552, 3.9602, 3.9652, 3.9701999999999997, 3.9752, 3.9802, 3.9852, 3.9901999999999997, 3.9952, 4.0001999999999995, 4.0052, 4.0102, 4.0152, 4.0202, 4.0252, 4.0302, 4.0352, 4.0402, 4.0452, 4.0502, 4.0552, 4.0602, 4.0652, 4.0702, 4.0752, 4.0802, 4.0852, 4.0902, 4.0952, 4.1002, 4.1052, 4.1102, 4.1152, 4.1202, 4.1251999999999995, 4.1302, 4.1352, 4.1402, 4.1452, 4.1502, 4.1552, 4.1602, 4.1652, 4.1702, 4.1752, 4.1802, 4.1852, 4.1902, 4.1952, 4.2002, 4.2052, 4.2102, 4.2152, 4.2202, 4.2252, 4.2302, 4.2352, 4.2402, 4.2452, 4.2501999999999995, 4.2552, 4.2602, 4.2652, 4.2702, 4.2752, 4.2802, 4.2852, 4.2902, 4.2952, 4.3002, 4.3052, 4.3102, 4.3152, 4.3202, 4.3252, 4.3302, 4.3352, 4.3402, 4.3452, 4.3502, 4.3552, 4.3602, 4.3652, 4.3702, 4.3751999999999995, 4.3802, 4.3852, 4.3902, 4.3952, 4.4002, 4.4052, 4.4102, 4.4152, 4.4202, 4.4252, 4.4302, 4.4352, 4.4402, 4.4452, 4.4502, 4.4552, 4.4602, 4.4652, 4.4702, 4.4752, 4.4802, 4.4852, 4.4902, 4.4952, 4.5001999999999995, 4.5052, 4.5102, 4.5152, 4.5202, 4.5252, 4.5302, 4.5352, 4.5402, 4.5451999999999995, 4.5502, 4.5552, 4.5602, 4.5652, 4.5702, 4.5752, 4.5802, 4.5852, 4.5902, 4.5952, 4.6002, 4.6052, 4.6102, 4.6152, 4.6202, 4.6251999999999995, 4.6302, 4.6352, 4.6402, 4.6452, 4.6502, 4.6552, 4.6602, 4.6652, 4.6701999999999995, 4.6752, 4.6802, 4.6852, 4.6902, 4.6952, 4.7002, 4.7052, 4.7102, 4.7152, 4.7202, 4.7252, 4.7302, 4.7352, 4.7402, 4.7452, 4.7501999999999995, 4.7552, 4.7602, 4.7652, 4.7702, 4.7752, 4.7802, 4.7852, 4.7902, 4.7951999999999995, 4.8002, 4.8052, 4.8102, 4.8152, 4.8202, 4.8252, 4.8302, 4.8352, 4.8402, 4.8452, 4.8502, 4.8552, 4.8602, 4.8652, 4.8702, 4.8751999999999995, 4.8802, 4.8852, 4.8902, 4.8952, 4.9002, 4.9052, 4.9102, 4.9152, 4.9201999999999995, 4.9252, 4.9302, 4.9352, 4.9402, 4.9452, 4.9502, 4.9552, 4.9602, 4.965199999999999, 4.9702, 4.9752, 4.9802, 4.9852, 4.9902, 4.9952, 5.0001999999999995, 5.0052, 5.0102, 5.0152, 5.0202, 5.0252, 5.0302, 5.0352, 5.0402000000000005, 5.0451999999999995, 5.0502, 5.0552, 5.0602, 5.0652, 5.0702, 5.0752, 5.0802, 5.0852, 5.090199999999999, 5.0952, 5.1002, 5.1052, 5.1102, 5.1152, 5.1202, 5.1251999999999995, 5.1302, 5.1352, 5.1402, 5.1452, 5.1502, 5.1552, 5.1602, 5.1652000000000005, 5.1701999999999995, 5.1752, 5.1802, 5.1852, 5.1902, 5.1952, 5.2002, 5.2052, 5.2102, 5.215199999999999, 5.2202, 5.2252, 5.2302, 5.2352, 5.2402, 5.2452, 5.2501999999999995, 5.2552, 5.2602, 5.2652, 5.2702, 5.2752, 5.2802, 5.2852, 5.2902000000000005, 5.2951999999999995, 5.3002, 5.3052, 5.3102, 5.3152, 5.3202, 5.3252, 5.3302, 5.3352, 5.340199999999999, 5.3452, 5.3502, 5.3552, 5.3602, 5.3652, 5.3702, 5.3751999999999995, 5.3802, 5.3852, 5.3902, 5.3952, 5.4002, 5.4052, 5.4102, 5.4152000000000005, 5.4201999999999995, 5.4252, 5.4302, 5.4352, 5.4402, 5.4452, 5.4502, 5.4552, 5.4602, 5.465199999999999, 5.4702, 5.4752, 5.4802, 5.4852, 5.4902, 5.4952, 5.5001999999999995, 5.5052, 5.5102, 5.5152, 5.5202, 5.5252, 5.5302, 5.5352, 5.5402000000000005, 5.5451999999999995, 5.5502, 5.5552, 5.5602, 5.5652, 5.5702, 5.5752, 5.5802, 5.5852, 5.590199999999999, 5.5952, 5.6002, 5.6052, 5.6102, 5.6152, 5.6202, 5.6251999999999995, 5.6302, 5.6352, 5.6402, 5.6452, 5.6502, 5.6552, 5.6602, 5.6652000000000005, 5.6701999999999995, 5.6752, 5.6802, 5.6852, 5.6902, 5.6952, 5.7002, 5.7052, 5.7102, 5.715199999999999, 5.7202, 5.7252, 5.7302, 5.7352, 5.7402, 5.7452, 5.7501999999999995, 5.7552, 5.7602, 5.7652, 5.7702, 5.7752, 5.7802, 5.7852, 5.7902000000000005, 5.7951999999999995, 5.8002, 5.8052, 5.8102, 5.8152, 5.8202, 5.8252, 5.8302, 5.8352, 5.840199999999999, 5.8452, 5.8502, 5.8552, 5.8602, 5.8652, 5.8702, 5.8751999999999995, 5.8802, 5.8852, 5.8902, 5.8952, 5.9002, 5.9052, 5.9102, 5.9152000000000005, 5.9201999999999995, 5.9252, 5.9302, 5.9352, 5.9402, 5.9452, 5.9502, 5.9552, 5.9602, 5.965199999999999, 5.9702, 5.9752, 5.9802, 5.9852, 5.9902, 5.9952000000000005, 6.0001999999999995, 6.0052, 6.010199999999999, 6.0152, 6.0202, 6.0252, 6.0302, 6.0352, 6.0402000000000005, 6.0451999999999995, 6.0502, 6.0552, 6.0602, 6.0652, 6.0702, 6.075200000000001, 6.0802, 6.0852, 6.090199999999999, 6.0952, 6.1002, 6.1052, 6.1102, 6.1152, 6.1202000000000005, 6.1251999999999995, 6.1302, 6.135199999999999, 6.1402, 6.1452, 6.1502, 6.1552, 6.1602, 6.1652000000000005, 6.1701999999999995, 6.1752, 6.1802, 6.1852, 6.1902, 6.1952, 6.200200000000001, 6.2052, 6.2102, 6.215199999999999, 6.2202, 6.2252, 6.2302, 6.2352, 6.2402, 6.2452000000000005, 6.2501999999999995, 6.2552, 6.260199999999999, 6.2652, 6.2702, 6.2752, 6.2802, 6.2852, 6.2902000000000005, 6.2951999999999995, 6.3002, 6.3052, 6.3102, 6.3152, 6.3202, 6.325200000000001, 6.3302, 6.3352, 6.340199999999999, 6.3452, 6.3502, 6.3552, 6.3602, 6.3652, 6.3702000000000005, 6.3751999999999995, 6.3802, 6.385199999999999, 6.3902, 6.3952, 6.4002, 6.4052, 6.4102, 6.4152000000000005, 6.4201999999999995, 6.4252, 6.4302, 6.4352, 6.4402, 6.4452, 6.450200000000001, 6.4552, 6.4602, 6.465199999999999, 6.4702, 6.4752, 6.4802, 6.4852, 6.4902, 6.4952000000000005, 6.5001999999999995, 6.5052, 6.510199999999999, 6.5152, 6.5202, 6.5252, 6.5302, 6.5352, 6.5402000000000005, 6.5451999999999995, 6.5502, 6.5552, 6.5602, 6.5652, 6.5702, 6.575200000000001, 6.5802, 6.5852, 6.590199999999999, 6.5952, 6.6002, 6.6052, 6.6102, 6.6152, 6.6202000000000005, 6.6251999999999995, 6.6302, 6.635199999999999, 6.6402, 6.6452, 6.6502, 6.6552, 6.6602, 6.6652000000000005, 6.6701999999999995, 6.6752, 6.6802, 6.6852, 6.6902, 6.6952, 6.700200000000001, 6.7052, 6.7102, 6.715199999999999, 6.7202, 6.7252, 6.7302, 6.7352, 6.7402, 6.7452000000000005, 6.7501999999999995, 6.7552, 6.760199999999999, 6.7652, 6.7702, 6.7752, 6.7802, 6.7852, 6.7902000000000005, 6.7951999999999995, 6.8002, 6.8052, 6.8102, 6.8152, 6.8202, 6.825200000000001, 6.8302, 6.8352, 6.840199999999999, 6.8452, 6.8502, 6.8552, 6.8602, 6.8652, 6.8702000000000005, 6.8751999999999995, 6.8802, 6.885199999999999, 6.8902, 6.8952, 6.9002, 6.9052, 6.9102, 6.9152000000000005, 6.9201999999999995, 6.9252, 6.9302, 6.9352, 6.9402, 6.9452, 6.950200000000001, 6.9552, 6.9602, 6.965199999999999, 6.9702, 6.9752, 6.9802, 6.9852, 6.9902, 6.9952000000000005, 7.0001999999999995, 7.0052, 7.010199999999999, 7.0152, 7.0202, 7.0252, 7.0302, 7.0352, 7.0402000000000005, 7.0451999999999995, 7.0502, 7.0552, 7.0602, 7.0652, 7.0702, 7.075200000000001, 7.0802, 7.0852, 7.090199999999999, 7.0952, 7.1002, 7.1052, 7.1102, 7.1152, 7.1202000000000005, 7.1251999999999995, 7.1302, 7.135199999999999, 7.1402, 7.1452, 7.1502, 7.1552, 7.1602, 7.1652000000000005, 7.1701999999999995, 7.1752, 7.1802, 7.1852, 7.1902, 7.1952, 7.200200000000001, 7.2052, 7.2102, 7.215199999999999, 7.2202, 7.2252, 7.2302, 7.2352, 7.2402, 7.2452000000000005, 7.2501999999999995, 7.2552, 7.260199999999999, 7.2652, 7.2702, 7.2752, 7.2802, 7.2852, 7.2902000000000005, 7.2951999999999995, 7.3002, 7.3052, 7.3102, 7.3152, 7.3202, 7.325200000000001, 7.3302, 7.3352, 7.340199999999999, 7.3452, 7.3502, 7.3552, 7.3602, 7.3652, 7.3702000000000005, 7.3751999999999995, 7.3802, 7.385199999999999, 7.3902, 7.3952, 7.4002, 7.4052, 7.4102, 7.4152000000000005, 7.4201999999999995, 7.4252, 7.4302, 7.4352, 7.4402, 7.4452, 7.450200000000001, 7.4552, 7.4602, 7.465199999999999, 7.4702, 7.4752, 7.4802, 7.4852, 7.4902, 7.4952000000000005, 7.5001999999999995, 7.5052, 7.510199999999999, 7.5152, 7.5202, 7.5252, 7.5302, 7.5352, 7.5402000000000005, 7.5451999999999995, 7.5502, 7.5552, 7.5602, 7.5652, 7.5702, 7.575200000000001, 7.5802, 7.5852, 7.590199999999999, 7.5952, 7.6002, 7.6052, 7.6102, 7.6152, 7.6202000000000005, 7.6251999999999995, 7.6302, 7.635199999999999, 7.6402, 7.6452, 7.6502, 7.6552, 7.6602, 7.6652000000000005, 7.6701999999999995, 7.6752, 7.6802, 7.6852, 7.6902, 7.6952, 7.700200000000001, 7.7052, 7.7102, 7.715199999999999, 7.7202, 7.7252, 7.7302, 7.7352, 7.7402, 7.7452000000000005, 7.7501999999999995, 7.7552, 7.760199999999999, 7.7652, 7.7702, 7.7752, 7.7802, 7.7852, 7.7902000000000005, 7.7951999999999995, 7.8002, 7.8052, 7.8102, 7.8152, 7.8202, 7.825200000000001, 7.8302, 7.8352, 7.840199999999999, 7.8452, 7.8502, 7.8552, 7.8602, 7.8652, 7.8702000000000005, 7.8751999999999995, 7.8802, 7.885199999999999, 7.8902, 7.8952, 7.9002, 7.9052, 7.9102, 7.9152000000000005, 7.9201999999999995, 7.9252, 7.9302, 7.9352, 7.9402, 7.9452, 7.950200000000001, 7.9552, 7.9602, 7.965199999999999, 7.9702, 7.975199999999999, 7.9802, 7.985200000000001, 7.9902, 7.9952000000000005, 8.0002, 8.0052, 8.0102, 8.0152, 8.020199999999999, 8.0252, 8.0302, 8.0352, 8.0402, 8.0452, 8.0502, 8.0552, 8.0602, 8.0652, 8.0702, 8.0752, 8.0802, 8.0852, 8.0902, 8.0952, 8.1002, 8.1052, 8.1102, 8.1152, 8.1202, 8.1252, 8.1302, 8.1352, 8.1402, 8.145199999999999, 8.1502, 8.1552, 8.1602, 8.1652, 8.1702, 8.1752, 8.1802, 8.1852, 8.1902, 8.1952, 8.2002, 8.2052, 8.2102, 8.2152, 8.2202, 8.2252, 8.2302, 8.2352, 8.2402, 8.2452, 8.2502, 8.2552, 8.2602, 8.2652, 8.270199999999999, 8.2752, 8.2802, 8.2852, 8.2902, 8.2952, 8.3002, 8.3052, 8.3102, 8.3152, 8.3202, 8.3252, 8.3302, 8.3352, 8.3402, 8.3452, 8.3502, 8.3552, 8.3602, 8.3652, 8.3702, 8.3752, 8.3802, 8.3852, 8.3902, 8.395199999999999, 8.4002, 8.4052, 8.4102, 8.4152, 8.4202, 8.4252, 8.4302, 8.4352, 8.4402, 8.4452, 8.4502, 8.4552, 8.4602, 8.4652, 8.4702, 8.4752, 8.4802, 8.4852, 8.4902, 8.4952, 8.5002, 8.5052, 8.5102, 8.5152, 8.520199999999999, 8.5252, 8.5302, 8.5352, 8.5402, 8.5452, 8.5502, 8.5552, 8.5602, 8.5652, 8.5702, 8.5752, 8.5802, 8.5852, 8.5902, 8.5952, 8.6002, 8.6052, 8.6102, 8.6152, 8.6202, 8.6252, 8.6302, 8.6352, 8.6402, 8.645199999999999, 8.6502, 8.6552, 8.6602, 8.6652, 8.6702, 8.6752, 8.6802, 8.6852, 8.6902, 8.6952, 8.7002, 8.7052, 8.7102, 8.7152, 8.7202, 8.7252, 8.7302, 8.7352, 8.7402, 8.7452, 8.7502, 8.7552, 8.7602, 8.7652, 8.770199999999999, 8.7752, 8.7802, 8.7852, 8.7902, 8.7952, 8.8002, 8.8052, 8.8102, 8.8152, 8.8202, 8.8252, 8.8302, 8.8352, 8.8402, 8.8452, 8.8502, 8.8552, 8.8602, 8.8652, 8.8702, 8.8752, 8.8802, 8.8852, 8.8902, 8.895199999999999, 8.9002, 8.9052, 8.9102, 8.9152, 8.9202, 8.9252, 8.9302, 8.9352, 8.9402, 8.9452, 8.9502, 8.9552, 8.9602, 8.9652, 8.9702, 8.9752, 8.9802, 8.9852, 8.9902, 8.9952, 9.0002, 9.0052, 9.0102, 9.0152, 9.020199999999999, 9.0252, 9.0302, 9.0352, 9.0402, 9.0452, 9.0502, 9.0552, 9.0602, 9.0652, 9.0702, 9.0752, 9.0802, 9.0852, 9.0902, 9.0952, 9.1002, 9.1052, 9.1102, 9.1152, 9.1202, 9.1252, 9.1302, 9.1352, 9.1402, 9.145199999999999, 9.1502, 9.1552, 9.1602, 9.1652, 9.1702, 9.1752, 9.1802, 9.1852, 9.1902, 9.1952, 9.2002, 9.2052, 9.2102, 9.2152, 9.2202, 9.2252, 9.2302, 9.2352, 9.2402, 9.2452, 9.2502, 9.2552, 9.2602, 9.2652, 9.270199999999999, 9.2752, 9.2802, 9.2852, 9.2902, 9.2952, 9.3002, 9.3052, 9.3102, 9.3152, 9.3202, 9.3252, 9.3302, 9.3352, 9.3402, 9.3452, 9.3502, 9.3552, 9.3602, 9.3652, 9.3702, 9.3752, 9.3802, 9.3852, 9.3902, 9.395199999999999, 9.4002, 9.4052, 9.4102, 9.4152, 9.4202, 9.4252, 9.4302, 9.4352, 9.4402, 9.4452, 9.4502, 9.4552, 9.4602, 9.4652, 9.4702, 9.4752, 9.4802, 9.4852, 9.4902, 9.4952, 9.5002, 9.5052, 9.5102, 9.5152, 9.520199999999999, 9.5252, 9.5302, 9.5352, 9.5402, 9.5452, 9.5502, 9.5552, 9.5602, 9.5652, 9.5702, 9.5752, 9.5802, 9.5852, 9.5902, 9.5952, 9.6002, 9.6052, 9.6102, 9.6152, 9.6202, 9.6252, 9.6302, 9.6352, 9.6402, 9.645199999999999, 9.6502, 9.6552, 9.6602, 9.6652, 9.6702, 9.6752, 9.6802, 9.6852, 9.6902, 9.6952, 9.7002, 9.7052, 9.7102, 9.7152, 9.7202, 9.7252, 9.7302, 9.7352, 9.7402, 9.7452, 9.7502, 9.7552, 9.7602, 9.7652, 9.770199999999999, 9.7752, 9.7802, 9.7852, 9.7902, 9.7952, 9.8002, 9.8052, 9.8102, 9.8152, 9.8202, 9.8252, 9.8302, 9.8352, 9.8402, 9.8452, 9.8502, 9.8552, 9.8602, 9.8652, 9.8702, 9.8752, 9.8802, 9.8852, 9.8902, 9.895199999999999, 9.9002, 9.9052, 9.9102, 9.9152, 9.9202, 9.9252, 9.9302, 9.9352, 9.9402, 9.9452, 9.9502, 9.9552, 9.9602, 9.9652, 9.9702, 9.9752, 9.9802, 9.9852, 9.9902, 9.9952, 10.0002, 10.0052, 10.0102, 10.0152, 10.020199999999999, 10.0252, 10.0302, 10.0352, 10.0402, 10.0452, 10.0502, 10.0552, 10.0602, 10.0652, 10.0702, 10.0752, 10.0802, 10.0852, 10.0902, 10.0952, 10.1002, 10.1052, 10.1102, 10.1152, 10.1202, 10.1252, 10.1302, 10.1352, 10.1402, 10.145199999999999, 10.1502, 10.1552, 10.1602, 10.1652, 10.1702, 10.1752, 10.1802, 10.1852, 10.1902, 10.1952, 10.2002, 10.2052, 10.2102, 10.2152, 10.2202, 10.2252, 10.2302, 10.2352, 10.2402, 10.2452, 10.2502, 10.2552, 10.2602, 10.2652, 10.270199999999999, 10.2752, 10.2802, 10.2852, 10.2902, 10.2952, 10.3002, 10.3052, 10.3102, 10.3152, 10.3202, 10.3252, 10.3302, 10.3352, 10.3402, 10.3452, 10.3502, 10.3552, 10.3602, 10.3652, 10.3702, 10.3752, 10.3802, 10.3852, 10.3902, 10.395199999999999, 10.4002, 10.4052, 10.4102, 10.4152, 10.4202, 10.4252, 10.4302, 10.4352, 10.4402, 10.4452, 10.4502, 10.4552, 10.4602, 10.4652, 10.4702, 10.4752, 10.4802, 10.4852, 10.4902, 10.4952, 10.5002, 10.5052, 10.5102, 10.5152, 10.520199999999999, 10.5252, 10.5302, 10.5352, 10.5402, 10.5452, 10.5502], list(map(lambda x: x.value, dos.conditions.scalars)))
        self.assertEquals([-4.957e-05, -8.501e-05, -0.0001428, -0.0002347, -0.0003778, -0.0005949, -0.0009164, -0.00138, -0.002032, -0.002921, -0.004097, -0.005601, -0.007451, -0.009628, -0.01205, -0.01455, -0.01686, -0.01856, -0.01913, -0.01787, -0.01402, -0.006742, 0.004777, 0.02122, 0.04303, 0.07032, 0.1028, 0.1397, 0.1798, 0.2217, 0.2637, 0.3041, 0.3417, 0.3754, 0.405, 0.4307, 0.4535, 0.4743, 0.4945, 0.5149, 0.536, 0.5575, 0.5781, 0.5962, 0.6094, 0.6155, 0.6125, 0.5994, 0.5763, 0.5447, 0.5074, 0.4682, 0.4316, 0.4025, 0.3849, 0.3817, 0.3946, 0.423, 0.4649, 0.5165, 0.5728, 0.6285, 0.6783, 0.7177, 0.7433, 0.7534, 0.7473, 0.7259, 0.6912, 0.6457, 0.5923, 0.5341, 0.4742, 0.4156, 0.3613, 0.3144, 0.2781, 0.2553, 0.2487, 0.2603, 0.2912, 0.3412, 0.4083, 0.4891, 0.5786, 0.6705, 0.758, 0.8342, 0.8928, 0.9293, 0.9407, 0.9267, 0.889, 0.8315, 0.7597, 0.68, 0.5986, 0.5214, 0.4528, 0.3957, 0.3512, 0.3189, 0.2974, 0.2847, 0.2787, 0.2781, 0.2822, 0.2912, 0.3061, 0.3283, 0.3593, 0.4, 0.4506, 0.5102, 0.5769, 0.648, 0.7202, 0.7898, 0.8534, 0.908, 0.9508, 0.98, 0.994, 0.992, 0.9734, 0.9384, 0.8878, 0.823, 0.7463, 0.6609, 0.5707, 0.4802, 0.394, 0.3165, 0.2515, 0.202, 0.1696, 0.1545, 0.1561, 0.1725, 0.2015, 0.2405, 0.2875, 0.3405, 0.3984, 0.4602, 0.5254, 0.5934, 0.6629, 0.7323, 0.799, 0.8599, 0.9116, 0.9506, 0.9745, 0.9819, 0.973, 0.9499, 0.9159, 0.8756, 0.8341, 0.7957, 0.764, 0.7407, 0.7254, 0.7162, 0.7093, 0.7002, 0.6843, 0.6577, 0.618, 0.5646, 0.4987, 0.4236, 0.3438, 0.265, 0.1931, 0.1338, 0.09214, 0.0719, 0.0756, 0.1042, 0.1572, 0.2324, 0.3267, 0.4356, 0.5538, 0.6757, 0.7955, 0.9078, 1.008, 1.092, 1.156, 1.2, 1.221, 1.222, 1.201, 1.161, 1.104, 1.033, 0.9513, 0.8631, 0.7732, 0.6866, 0.6085, 0.5437, 0.4961, 0.4679, 0.4598, 0.4701, 0.495, 0.5292, 0.5661, 0.5985, 0.6201, 0.6255, 0.6116, 0.5776, 0.5251, 0.4584, 0.3835, 0.3081, 0.2402, 0.1879, 0.1582, 0.1568, 0.1871, 0.25, 0.3439, 0.4643, 0.6047, 0.7564, 0.9099, 1.055, 1.184, 1.287, 1.361, 1.403, 1.413, 1.394, 1.351, 1.291, 1.218, 1.138, 1.054, 0.9707, 0.8876, 0.8058, 0.7255, 0.6472, 0.5724, 0.5031, 0.4424, 0.3935, 0.3597, 0.3433, 0.3451, 0.3641, 0.3975, 0.4405, 0.4875, 0.5322, 0.5689, 0.5931, 0.6025, 0.5971, 0.5795, 0.5544, 0.5283, 0.5083, 0.5012, 0.5127, 0.5467, 0.6046, 0.6849, 0.7838, 0.8953, 1.012, 1.126, 1.229, 1.316, 1.38, 1.421, 1.437, 1.431, 1.408, 1.374, 1.334, 1.295, 1.262, 1.236, 1.221, 1.213, 1.212, 1.213, 1.214, 1.211, 1.202, 1.188, 1.169, 1.149, 1.13, 1.117, 1.112, 1.119, 1.139, 1.172, 1.218, 1.276, 1.344, 1.42, 1.501, 1.585, 1.67, 1.752, 1.83, 1.902, 1.965, 2.019, 2.062, 2.096, 2.12, 2.137, 2.149, 2.158, 2.166, 2.176, 2.186, 2.198, 2.208, 2.215, 2.213, 2.2, 2.171, 2.124, 2.057, 1.969, 1.863, 1.741, 1.61, 1.475, 1.345, 1.228, 1.132, 1.066, 1.035, 1.043, 1.094, 1.184, 1.312, 1.471, 1.653, 1.848, 2.046, 2.237, 2.412, 2.562, 2.682, 2.768, 2.818, 2.834, 2.819, 2.777, 2.713, 2.635, 2.549, 2.462, 2.379, 2.305, 2.242, 2.193, 2.158, 2.135, 2.122, 2.115, 2.112, 2.11, 2.105, 2.096, 2.083, 2.067, 2.052, 2.041, 2.04, 2.056, 2.095, 2.163, 2.262, 2.396, 2.563, 2.76, 2.98, 3.213, 3.448, 3.674, 3.877, 4.046, 4.17, 4.243, 4.261, 4.223, 4.133, 3.998, 3.829, 3.639, 3.441, 3.25, 3.079, 2.94, 2.843, 2.791, 2.786, 2.824, 2.897, 2.993, 3.095, 3.189, 3.257, 3.286, 3.267, 3.196, 3.074, 2.911, 2.72, 2.52, 2.332, 2.175, 2.066, 2.015, 2.029, 2.104, 2.232, 2.398, 2.584, 2.769, 2.936, 3.068, 3.153, 3.185, 3.164, 3.094, 2.983, 2.842, 2.684, 2.519, 2.358, 2.208, 2.072, 1.952, 1.846, 1.751, 1.664, 1.583, 1.505, 1.433, 1.368, 1.316, 1.281, 1.268, 1.278, 1.313, 1.37, 1.443, 1.526, 1.607, 1.68, 1.734, 1.763, 1.763, 1.733, 1.673, 1.589, 1.485, 1.368, 1.247, 1.127, 1.017, 0.9197, 0.8411, 0.784, 0.75, 0.7399, 0.7538, 0.7907, 0.8497, 0.929, 1.027, 1.14, 1.266, 1.401, 1.539, 1.674, 1.801, 1.913, 2.002, 2.064, 2.094, 2.091, 2.054, 1.985, 1.89, 1.773, 1.643, 1.508, 1.374, 1.251, 1.145, 1.062, 1.007, 0.9842, 0.9966, 1.045, 1.13, 1.249, 1.399, 1.573, 1.764, 1.963, 2.157, 2.337, 2.49, 2.608, 2.681, 2.705, 2.68, 2.608, 2.496, 2.354, 2.195, 2.036, 1.892, 1.781, 1.717, 1.716, 1.784, 1.928, 2.144, 2.425, 2.753, 3.108, 3.463, 3.789, 4.061, 4.255, 4.355, 4.354, 4.255, 4.071, 3.824, 3.538, 3.242, 2.964, 2.724, 2.539, 2.415, 2.351, 2.339, 2.365, 2.412, 2.464, 2.504, 2.522, 2.511, 2.47, 2.401, 2.313, 2.215, 2.117, 2.028, 1.956, 1.903, 1.871, 1.858, 1.859, 1.866, 1.875, 1.877, 1.868, 1.843, 1.8, 1.738, 1.656, 1.556, 1.441, 1.313, 1.175, 1.03, 0.8835, 0.7382, 0.5983, 0.4675, 0.3488, 0.2447, 0.1566, 0.08505, 0.0298, -0.01035, -0.03718, -0.05286, -0.05977, -0.0602, -0.05627, -0.04975, -0.04206, -0.03422, -0.02691, -0.02052, -0.0152, -0.01095, -0.007687, -0.005262, -0.003515, -0.002293, -0.001461, -0.0009103, -0.0005545, -0.0003303, -0.0001925, -0.0001098, -6.128e-05, -3.349e-05, -1.792e-05, -9.385e-06, -4.815e-06, -2.419e-06, -1.191e-06, -5.741e-07, -2.712e-07, -1.255e-07, -5.688e-08, -2.527e-08, -1.1e-08, -4.691e-09, -1.96e-09, -8.028e-10, -3.222e-10, -1.267e-10, -4.884e-11, -1.845e-11, -6.829e-12, -2.477e-12, -8.807e-13, -3.069e-13, -1.048e-13, -3.507e-14, -1.15e-14, -3.696e-15, -1.164e-15, -3.595e-16, -1.088e-16, -3.225e-17, -9.372e-18, -2.669e-18, -7.451e-19, -2.038e-19, -5.464e-20, -1.435e-20, -3.696e-21, -9.327e-22, -2.307e-22, -5.59e-23, -1.328e-23, -3.091e-24, -7.052e-25, -1.577e-25, -3.454e-26, -7.417e-27, -1.561e-27, -3.219e-28, -6.506e-29, -1.289e-29, -2.502e-30, -4.759e-31, -8.874e-32, -1.621e-32, -2.903e-33, -5.095e-34, -8.763e-35, -1.477e-35, -2.44e-36, -3.95e-37, -6.266e-38, -9.743e-39, -1.485e-39, -2.217e-40, -3.245e-41, -4.654e-42, -6.542e-43, -9.013e-44, -1.217e-44, -1.61e-45, -2.088e-46, -2.654e-47, -3.305e-48, -4.035e-49, -4.827e-50, -5.66e-51, -6.504e-52, -7.324e-53, -8.084e-54, -8.745e-55, -9.271e-56, -9.632e-57, -9.808e-58, -9.789e-59, -9.574e-60, -9.178e-61, -8.623e-62, -7.94e-63, -7.165e-64, -6.337e-65, -5.493e-66, -4.667e-67, -3.886e-68, -3.171e-69, -2.536e-70, -1.988e-71, -1.527e-72, -1.15e-73, -8.486e-75, -6.138e-76, -4.354e-77, -3.05e-78, -2.329e-79, -4.083e-80, -2.797e-80, -2.711e-80, -2.704e-80, -2.701e-80, -2.699e-80, -2.697e-80, -2.695e-80, -2.693e-80, -2.691e-80, -2.689e-80, -2.687e-80, -2.685e-80, -2.683e-80, -2.681e-80, -2.679e-80, -2.677e-80, -2.675e-80, -2.673e-80, -2.671e-80, -2.669e-80, -2.667e-80, -2.666e-80, -2.664e-80, -2.662e-80, -2.66e-80, -2.658e-80, -2.656e-80, -2.654e-80, -2.652e-80, -2.65e-80, -2.648e-80, -2.646e-80, -2.644e-80, -2.642e-80, -2.64e-80, -2.638e-80, -2.636e-80, -2.634e-80, -2.632e-80, -2.63e-80, -2.628e-80, -2.626e-80, -2.624e-80, -2.622e-80, -2.62e-80, -2.618e-80, -2.616e-80, -2.614e-80, -2.612e-80, -2.61e-80, -2.608e-80, -2.606e-80, -2.604e-80, -2.602e-80, -2.6e-80, -2.599e-80, -2.597e-80, -2.595e-80, -2.593e-80, -2.591e-80, -2.589e-80, -2.587e-80, -2.585e-80, -2.583e-80, -2.581e-80, -2.579e-80, -2.577e-80, -2.575e-80, -2.573e-80, -2.571e-80, -2.569e-80, -2.567e-80, -2.565e-80, -2.564e-80, -2.562e-80, -2.56e-80, -2.558e-80, -2.556e-80, -2.554e-80, -2.552e-80, -2.55e-80, -2.548e-80, -2.546e-80, -2.544e-80, -2.542e-80, -2.54e-80, -2.538e-80, -2.537e-80, -2.535e-80, -2.533e-80, -2.531e-80, -2.529e-80, -2.527e-80, -2.525e-80, -2.523e-80, -2.521e-80, -2.519e-80, -2.517e-80, -2.515e-80, -2.514e-80, -2.512e-80, -2.51e-80, -2.508e-80, -2.506e-80, -2.504e-80, -2.502e-80, -2.5e-80, -2.498e-80, -2.496e-80, -2.495e-80, -2.493e-80, -2.491e-80, -2.489e-80, -2.487e-80, -2.485e-80, -2.483e-80, -2.481e-80, -2.479e-80, -2.477e-80, -2.476e-80, -2.474e-80, -2.472e-80, -2.47e-80, -2.468e-80, -2.466e-80, -2.464e-80, -2.462e-80, -2.461e-80, -2.459e-80, -2.457e-80, -2.455e-80, -2.453e-80, -2.451e-80, -2.449e-80, -2.447e-80, -2.446e-80, -2.444e-80, -2.442e-80, -2.44e-80, -2.438e-80, -2.436e-80, -2.434e-80, -2.432e-80, -2.431e-80, -2.429e-80, -2.427e-80, -2.425e-80, -2.423e-80, -2.421e-80, -2.419e-80, -2.418e-80, -2.416e-80, -2.414e-80, -2.412e-80, -2.41e-80, -2.408e-80, -2.406e-80, -2.405e-80, -2.403e-80, -2.401e-80, -2.399e-80, -2.397e-80, -2.395e-80, -2.393e-80, -2.392e-80, -2.39e-80, -2.388e-80, -2.386e-80, -2.384e-80, -2.382e-80, -2.381e-80, -2.379e-80, -2.377e-80, -2.375e-80, -2.373e-80, -2.371e-80, -2.37e-80, -2.368e-80, -2.366e-80, -2.364e-80, -2.362e-80, -2.36e-80, -2.359e-80, -2.357e-80, -2.355e-80, -2.353e-80, -2.351e-80, -2.349e-80, -2.348e-80, -2.346e-80, -2.344e-80, -2.342e-80, -2.34e-80, -2.339e-80, -2.337e-80, -2.335e-80, -2.333e-80, -2.331e-80, -2.33e-80, -2.328e-80, -2.326e-80, -2.324e-80, -2.322e-80, -2.32e-80, -2.319e-80, -2.317e-80, -2.315e-80, -2.313e-80, -2.311e-80, -2.31e-80, -2.308e-80, -2.306e-80, -2.304e-80, -2.302e-80, -2.301e-80, -2.299e-80, -2.297e-80, -2.295e-80, -2.294e-80, -2.292e-80, -2.29e-80, -2.288e-80, -2.286e-80, -2.285e-80, -2.283e-80, -2.281e-80, -2.279e-80, -2.277e-80, -2.276e-80, -2.274e-80, -2.272e-80, -2.27e-80, -2.269e-80, -2.267e-80, -2.265e-80, -2.263e-80, -2.261e-80, -2.26e-80, -2.258e-80, -2.256e-80, -2.254e-80, -2.253e-80, -2.251e-80, -2.249e-80, -2.247e-80, -2.246e-80, -2.244e-80, -2.242e-80, -2.24e-80, -2.238e-80, -2.237e-80, -2.235e-80, -2.233e-80, -2.231e-80, -2.23e-80, -2.228e-80, -2.226e-80, -2.224e-80, -2.223e-80, -2.221e-80, -2.219e-80, -2.217e-80, -2.216e-80, -2.214e-80, -2.212e-80, -2.21e-80, -2.209e-80, -2.207e-80, -2.205e-80, -2.204e-80, -2.202e-80, -2.2e-80, -2.198e-80, -2.197e-80, -2.195e-80, -2.193e-80, -2.191e-80, -2.19e-80, -2.188e-80, -2.186e-80, -2.184e-80, -2.183e-80, -2.181e-80, -2.179e-80, -2.178e-80, -2.176e-80, -2.174e-80, -2.172e-80, -2.171e-80, -2.169e-80, -2.167e-80, -2.166e-80, -2.164e-80, -2.162e-80, -2.16e-80, -2.159e-80, -2.157e-80, -2.155e-80, -2.154e-80, -2.152e-80, -2.15e-80, -2.148e-80, -2.147e-80, -2.145e-80, -2.143e-80, -2.142e-80, -2.14e-80, -2.138e-80, -2.136e-80, -2.135e-80, -2.133e-80, -2.131e-80, -2.13e-80, -2.128e-80, -2.126e-80, -2.125e-80, -2.123e-80, -2.121e-80, -2.12e-80, -2.118e-80, -2.116e-80, -2.114e-80, -2.113e-80, -2.111e-80, -2.109e-80, -2.108e-80, -2.106e-80, -2.104e-80, -2.103e-80, -2.101e-80, -2.099e-80, -2.098e-80, -2.096e-80, -2.094e-80, -2.093e-80, -2.091e-80, -2.089e-80, -2.088e-80, -2.086e-80, -2.084e-80, -2.083e-80, -2.081e-80, -2.079e-80, -2.078e-80, -2.076e-80, -2.074e-80, -2.073e-80, -2.071e-80, -2.069e-80, -2.068e-80, -2.066e-80, -2.064e-80, -2.063e-80, -2.061e-80, -2.059e-80, -2.058e-80, -2.056e-80, -2.054e-80, -2.053e-80, -2.051e-80, -2.049e-80, -2.048e-80, -2.046e-80, -2.044e-80, -2.043e-80, -2.041e-80, -2.04e-80, -2.038e-80, -2.036e-80, -2.035e-80, -2.033e-80, -2.031e-80, -2.03e-80, -2.028e-80, -2.026e-80, -2.025e-80, -2.023e-80, -2.022e-80, -2.02e-80, -2.018e-80, -2.017e-80, -2.015e-80, -2.013e-80, -2.012e-80, -2.01e-80, -2.009e-80, -2.007e-80, -2.005e-80, -2.004e-80, -2.002e-80, -2e-80, -1.999e-80, -1.997e-80, -1.996e-80, -1.994e-80, -1.992e-80, -1.991e-80, -1.989e-80, -1.988e-80, -1.986e-80, -1.984e-80, -1.983e-80, -1.981e-80, -1.979e-80, -1.978e-80, -1.976e-80, -1.975e-80, -1.973e-80, -1.971e-80, -1.97e-80, -1.968e-80, -1.967e-80, -1.965e-80, -1.963e-80, -1.962e-80, -1.96e-80, -1.959e-80, -1.957e-80, -1.956e-80, -1.954e-80, -1.952e-80, -1.951e-80, -1.949e-80, -1.948e-80, -1.946e-80, -1.944e-80, -1.943e-80, -1.941e-80, -1.94e-80, -1.938e-80, -1.936e-80, -1.935e-80, -1.933e-80, -1.932e-80, -1.93e-80, -1.929e-80, -1.927e-80, -1.925e-80, -1.924e-80, -1.922e-80, -1.921e-80, -1.919e-80, -1.918e-80, -1.916e-80, -1.915e-80, -1.913e-80, -1.911e-80, -1.91e-80, -1.908e-80, -1.907e-80, -1.905e-80, -1.904e-80, -1.902e-80, -1.9e-80, -1.899e-80, -1.897e-80, -1.896e-80, -1.894e-80, -1.893e-80, -1.891e-80, -1.89e-80, -1.888e-80, -1.887e-80, -1.885e-80, -1.883e-80, -1.882e-80, -1.88e-80, -1.879e-80, -1.877e-80, -1.876e-80, -1.874e-80, -1.873e-80, -1.871e-80, -1.87e-80, -1.868e-80, -1.866e-80, -1.865e-80, -1.863e-80, -1.862e-80, -1.86e-80, -1.859e-80, -1.857e-80, -1.856e-80, -1.854e-80, -1.853e-80, -1.851e-80, -1.85e-80, -1.848e-80, -1.847e-80, -1.845e-80, -1.844e-80, -1.842e-80, -1.841e-80, -1.839e-80, -1.838e-80, -1.836e-80, -1.835e-80, -1.833e-80, -1.832e-80, -1.83e-80, -1.828e-80, -1.827e-80, -1.825e-80, -1.824e-80, -1.822e-80, -1.821e-80, -1.819e-80, -1.818e-80, -1.816e-80, -1.815e-80, -1.813e-80, -1.812e-80, -1.81e-80, -1.809e-80, -1.807e-80, -1.806e-80, -1.804e-80, -1.803e-80, -1.801e-80, -1.8e-80, -1.799e-80, -1.797e-80, -1.796e-80, -1.794e-80, -1.793e-80, -1.791e-80, -1.79e-80, -1.788e-80, -1.787e-80, -1.785e-80, -1.784e-80, -1.782e-80, -1.781e-80, -1.779e-80, -1.778e-80, -1.776e-80, -1.775e-80, -1.773e-80, -1.772e-80, -1.77e-80, -1.769e-80, -1.767e-80, -1.766e-80, -1.765e-80, -1.763e-80, -1.762e-80, -1.76e-80, -1.759e-80, -1.757e-80, -1.756e-80, -1.754e-80, -1.753e-80, -1.751e-80, -1.75e-80, -1.749e-80, -1.747e-80, -1.746e-80, -1.744e-80, -1.743e-80, -1.741e-80, -1.74e-80, -1.738e-80, -1.737e-80, -1.735e-80, -1.734e-80, -1.733e-80, -1.731e-80, -1.73e-80, -1.728e-80, -1.727e-80, -1.725e-80, -1.724e-80, -1.722e-80, -1.721e-80, -1.72e-80, -1.718e-80, -1.717e-80, -1.715e-80, -1.714e-80, -1.712e-80, -1.711e-80, -1.71e-80, -1.708e-80, -1.707e-80, -1.705e-80, -1.704e-80, -1.702e-80, -1.701e-80, -1.7e-80, -1.698e-80, -1.697e-80, -1.695e-80, -1.694e-80, -1.693e-80, -1.691e-80, -1.69e-80, -1.688e-80, -1.687e-80, -1.685e-80, -1.684e-80, -1.683e-80, -1.681e-80, -1.68e-80, -1.678e-80, -1.677e-80, -1.676e-80, -1.674e-80, -1.673e-80, -1.671e-80, -1.67e-80, -1.669e-80, -1.667e-80, -1.666e-80, -1.664e-80, -1.663e-80, -1.662e-80, -1.66e-80, -1.659e-80, -1.657e-80, -1.656e-80, -1.655e-80, -1.653e-80, -1.652e-80, -1.651e-80, -1.649e-80, -1.648e-80, -1.646e-80, -1.645e-80, -1.644e-80, -1.642e-80, -1.641e-80, -1.639e-80, -1.638e-80, -1.637e-80, -1.635e-80, -1.634e-80, -1.633e-80, -1.631e-80, -1.63e-80, -1.629e-80, -1.627e-80, -1.626e-80, -1.624e-80, -1.623e-80, -1.622e-80, -1.62e-80, -1.619e-80, -1.618e-80, -1.616e-80, -1.615e-80, -1.614e-80, -1.612e-80, -1.611e-80, -1.609e-80, -1.608e-80, -1.607e-80, -1.605e-80, -1.604e-80, -1.603e-80, -1.601e-80, -1.6e-80, -1.599e-80, -1.597e-80, -1.596e-80, -1.595e-80, -1.593e-80, -1.592e-80, -1.591e-80, -1.589e-80, -1.588e-80, -1.587e-80, -1.585e-80, -1.584e-80, -1.583e-80, -1.581e-80, -1.58e-80, -1.579e-80, -1.577e-80, -1.576e-80, -1.575e-80, -1.573e-80, -1.572e-80, -1.571e-80, -1.569e-80, -1.568e-80, -1.567e-80, -1.565e-80, -1.564e-80, -1.563e-80, -1.561e-80, -1.56e-80, -1.559e-80, -1.557e-80, -1.556e-80, -1.555e-80, -1.553e-80, -1.552e-80, -1.551e-80, -1.549e-80, -1.548e-80, -1.547e-80, -1.546e-80, -1.544e-80, -1.543e-80, -1.542e-80, -1.54e-80, -1.539e-80, -1.538e-80, -1.536e-80, -1.535e-80, -1.534e-80, -1.533e-80, -1.531e-80, -1.53e-80, -1.529e-80, -1.527e-80, -1.526e-80, -1.525e-80, -1.523e-80, -1.522e-80, -1.521e-80, -1.52e-80, -1.518e-80, -1.517e-80, -1.516e-80, -1.514e-80, -1.513e-80, -1.512e-80, -1.511e-80, -1.509e-80, -1.508e-80, -1.507e-80, -1.505e-80, -1.504e-80, -1.503e-80, -1.502e-80, -1.5e-80, -1.499e-80, -1.498e-80, -1.497e-80, -1.495e-80, -1.494e-80, -1.493e-80, -1.492e-80, -1.49e-80, -1.489e-80, -1.488e-80, -1.486e-80, -1.485e-80, -1.484e-80, -1.483e-80, -1.481e-80, -1.48e-80, -1.479e-80, -1.478e-80, -1.476e-80, -1.475e-80, -1.474e-80, -1.473e-80, -1.471e-80, -1.47e-80, -1.469e-80, -1.468e-80, -1.466e-80, -1.465e-80, -1.464e-80, -1.463e-80, -1.461e-80, -1.46e-80, -1.459e-80, -1.458e-80, -1.456e-80, -1.455e-80, -1.454e-80, -1.453e-80, -1.452e-80, -1.45e-80, -1.449e-80, -1.448e-80, -1.447e-80, -1.445e-80, -1.444e-80, -1.443e-80, -1.442e-80, -1.44e-80, -1.439e-80, -1.438e-80, -1.437e-80, -1.436e-80, -1.434e-80, -1.433e-80, -1.432e-80, -1.431e-80, -1.43e-80, -1.428e-80, -1.427e-80, -1.426e-80, -1.425e-80, -1.423e-80, -1.422e-80, -1.421e-80, -1.42e-80, -1.419e-80, -1.417e-80, -1.416e-80, -1.415e-80, -1.414e-80, -1.413e-80, -1.411e-80, -1.41e-80, -1.409e-80, -1.408e-80, -1.407e-80, -1.405e-80, -1.404e-80, -1.403e-80, -1.402e-80, -1.401e-80, -1.399e-80, -1.398e-80, -1.397e-80, -1.396e-80, -1.395e-80, -1.393e-80, -1.392e-80, -1.391e-80, -1.39e-80, -1.389e-80, -1.388e-80, -1.386e-80, -1.385e-80, -1.384e-80, -1.383e-80, -1.382e-80, -1.381e-80, -1.379e-80, -1.378e-80, -1.377e-80, -1.376e-80, -1.375e-80, -1.373e-80, -1.372e-80, -1.371e-80, -1.37e-80, -1.369e-80, -1.368e-80, -1.366e-80, -1.365e-80, -1.364e-80, -1.363e-80, -1.362e-80, -1.361e-80, -1.36e-80, -1.358e-80, -1.357e-80, -1.356e-80, -1.355e-80, -1.354e-80, -1.353e-80, -1.351e-80, -1.35e-80, -1.349e-80, -1.348e-80, -1.347e-80, -1.346e-80, -1.346e-80, -1.365e-80, -1.684e-80, -6.522e-80, -7.844e-79, -1.126e-77, -1.607e-76, -2.252e-75, -3.092e-74, -4.16e-73, -5.487e-72, -7.092e-71, -8.985e-70, -1.116e-68, -1.358e-67, -1.619e-66, -1.892e-65, -2.168e-64, -2.434e-63, -2.678e-62, -2.888e-61, -3.052e-60, -3.162e-59, -3.209e-58, -3.193e-57, -3.113e-56, -2.975e-55, -2.786e-54, -2.557e-53, -2.3e-52, -2.028e-51, -1.752e-50, -1.483e-49, -1.231e-48, -1.001e-47, -7.975e-47, -6.228e-46, -4.767e-45, -3.576e-44, -2.628e-43, -1.893e-42, -1.337e-41, -9.247e-41, -6.269e-40, -4.165e-39, -2.712e-38, -1.73e-37, -1.082e-36, -6.63e-36, -3.981e-35, -2.342e-34, -1.351e-33, -7.631e-33, -4.225e-32, -2.292e-31, -1.219e-30, -6.35e-30, -3.242e-29, -1.622e-28, -7.949e-28, -3.818e-27, -1.797e-26, -8.287e-26, -3.745e-25, -1.658e-24, -7.193e-24, -3.058e-23, -1.273e-22, -5.196e-22, -2.078e-21, -8.138e-21, -3.123e-20, -1.174e-19, -4.327e-19, -1.562e-18, -5.521e-18, -1.913e-17, -6.49e-17, -2.158e-16, -7.027e-16, -2.242e-15, -7.005e-15, -2.144e-14, -6.429e-14, -1.888e-13, -5.432e-13, -1.53e-12, -4.223e-12, -1.141e-11, -3.02e-11, -7.828e-11, -1.987e-10, -4.938e-10, -1.202e-09, -2.863e-09, -6.68e-09, -1.526e-08, -3.411e-08, -7.465e-08, -1.599e-07, -3.353e-07, -6.881e-07, -1.382e-06, -2.715e-06, -5.22e-06, -9.817e-06, -1.806e-05, -3.249e-05, -5.717e-05, -9.836e-05, -0.0001654, -0.000272, -0.0004369, -0.0006857, -0.001051, -0.001574, -0.0023, -0.003279, -0.004559, -0.006178, -0.008153, -0.01047, -0.01306, -0.01579, -0.01845, -0.02076, -0.0223, -0.02258, -0.02101, -0.01689, -0.009437, 0.002204, 0.01896, 0.04179, 0.07166, 0.1095, 0.1559, 0.2115, 0.2764, 0.3499, 0.4311, 0.518, 0.6082, 0.6983, 0.7847, 0.8636, 0.9313, 0.9842, 1.02, 1.037, 1.034, 1.012, 0.9718, 0.917, 0.8509, 0.7777, 0.7026, 0.6312, 0.5693, 0.5226, 0.4963, 0.4945, 0.5195, 0.5717, 0.6489, 0.7464, 0.8576, 0.974, 1.086, 1.186, 1.265, 1.318, 1.343, 1.34, 1.313, 1.267, 1.209, 1.145, 1.083, 1.025, 0.9755, 0.9333, 0.897, 0.8639, 0.8302, 0.7928, 0.7492, 0.6981, 0.6403, 0.5782, 0.5157, 0.4583, 0.4121, 0.3835, 0.3781, 0.4006, 0.4531, 0.5354, 0.6444, 0.7741, 0.9158, 1.06, 1.195, 1.311, 1.4, 1.458, 1.482, 1.477, 1.447, 1.402, 1.352, 1.307, 1.275, 1.261, 1.268, 1.293, 1.33, 1.371, 1.407, 1.428, 1.427, 1.397, 1.338, 1.251, 1.141, 1.014, 0.8786, 0.7445, 0.6202, 0.5137, 0.4318, 0.3802, 0.3635, 0.3852, 0.4475, 0.5511, 0.695, 0.8757, 1.087, 1.322, 1.567, 1.811, 2.04, 2.242, 2.405, 2.524, 2.596, 2.621, 2.606, 2.561, 2.496, 2.425, 2.356, 2.298, 2.255, 2.227, 2.21, 2.197, 2.179, 2.147, 2.093, 2.011, 1.899, 1.758, 1.593, 1.414, 1.232, 1.06, 0.9099, 0.7955, 0.7268, 0.7111, 0.7523, 0.8499, 0.9994, 1.192, 1.417, 1.659, 1.904, 2.138, 2.35, 2.53, 2.675, 2.786, 2.866, 2.923, 2.966, 3.004, 3.041, 3.082, 3.125, 3.165, 3.197, 3.21, 3.196, 3.148, 3.061, 2.937, 2.778, 2.591, 2.388, 2.181, 1.983, 1.806, 1.661, 1.556, 1.498, 1.487, 1.524, 1.605, 1.721, 1.865, 2.024, 2.188, 2.342, 2.475, 2.576, 2.635, 2.647, 2.608, 2.519, 2.384, 2.21, 2.007, 1.785, 1.558, 1.338, 1.136, 0.9631, 0.8271, 0.7345, 0.6898, 0.696, 0.754, 0.8638, 1.024, 1.231, 1.48, 1.765, 2.077, 2.407, 2.744, 3.077, 3.396, 3.693, 3.962, 4.202, 4.413, 4.599, 4.767, 4.926, 5.083, 5.247, 5.421, 5.609, 5.809, 6.018, 6.229, 6.431, 6.612, 6.759, 6.861, 6.907, 6.888, 6.802, 6.649, 6.437, 6.176, 5.88, 5.566, 5.251, 4.95, 4.674, 4.432, 4.222, 4.042, 3.881, 3.728, 3.568, 3.39, 3.184, 2.946, 2.676, 2.38, 2.069, 1.76, 1.468, 1.212, 1.006, 0.8621, 0.7864, 0.7796, 0.8357, 0.9436, 1.087, 1.247, 1.404, 1.54, 1.639, 1.69, 1.69, 1.639, 1.544, 1.418, 1.272, 1.123, 0.985, 0.8685, 0.7822, 0.7309, 0.7156, 0.7348, 0.7847, 0.8604, 0.9562, 1.067, 1.186, 1.308, 1.428, 1.538, 1.633, 1.705, 1.748, 1.757, 1.728, 1.66, 1.555, 1.416, 1.25, 1.066, 0.8744, 0.684, 0.5048, 0.3451, 0.2116, 0.109, 0.04035, 0.006949, 0.008612, 0.04391, 0.1104, 0.2046, 0.3223, 0.4585, 0.6076, 0.7634, 0.9195, 1.069, 1.207, 1.327, 1.425, 1.497, 1.544, 1.563, 1.558, 1.531, 1.484, 1.422, 1.347, 1.263, 1.171, 1.074, 0.9715, 0.8648, 0.7544, 0.6415, 0.5279, 0.4159, 0.3087, 0.2101, 0.1244, 0.05606, 0.009524, -0.01119, -0.002733, 0.03728, 0.1099, 0.2146, 0.3489, 0.5085, 0.6869, 0.876, 1.066, 1.247, 1.409, 1.542, 1.637, 1.691, 1.699, 1.664, 1.589, 1.48, 1.349, 1.207, 1.066, 0.9394, 0.8386, 0.7734, 0.7506, 0.7738, 0.8426, 0.9535, 1.1, 1.273, 1.462, 1.66, 1.856, 2.046, 2.226, 2.394, 2.554, 2.706, 2.855, 3.004, 3.154, 3.306, 3.458, 3.608, 3.749, 3.879, 3.994, 4.09, 4.165, 4.222, 4.26, 4.283, 4.294, 4.295, 4.287, 4.27, 4.244, 4.207, 4.157, 4.095, 4.022, 3.943, 3.866, 3.801, 3.759, 3.751, 3.787, 3.874, 4.017, 4.215, 4.465, 4.758, 5.086, 5.436, 5.796, 6.155, 6.502, 6.824, 7.113, 7.36, 7.557, 7.696, 7.773, 7.782, 7.722, 7.592, 7.396, 7.139, 6.828, 6.473, 6.087, 5.681, 5.269, 4.862, 4.47, 4.101, 3.762, 3.454, 3.178, 2.934, 2.719, 2.531, 2.365, 2.222, 2.099, 1.996, 1.913, 1.847, 1.799, 1.765, 1.742, 1.725, 1.71, 1.691, 1.666, 1.63, 1.585, 1.532, 1.472, 1.412, 1.356, 1.308, 1.272, 1.251, 1.245, 1.254, 1.274, 1.302, 1.335, 1.368, 1.398, 1.422, 1.437, 1.441, 1.434, 1.414, 1.383, 1.34, 1.286, 1.225, 1.159, 1.09, 1.024, 0.9631, 0.9135, 0.8796, 0.8664, 0.8785, 0.9197, 0.9928, 1.098, 1.235, 1.399, 1.585, 1.782, 1.982, 2.173, 2.345, 2.489, 2.597, 2.666, 2.692, 2.678, 2.626, 2.54, 2.424, 2.285, 2.128, 1.957, 1.777, 1.594, 1.41, 1.23, 1.057, 0.8923, 0.7392, 0.5985, 0.4711, 0.3576, 0.2586, 0.1753, 0.109, 0.06212, 0.03718, 0.03715, 0.06469, 0.1217, 0.2089, 0.3252, 0.4674, 0.6307, 0.8085, 0.9937, 1.179, 1.357, 1.525, 1.678, 1.817, 1.944, 2.062, 2.174, 2.282, 2.389, 2.492, 2.589, 2.674, 2.742, 2.787, 2.808, 2.802, 2.776, 2.734, 2.687, 2.646, 2.622, 2.624, 2.658, 2.725, 2.821, 2.94, 3.068, 3.194, 3.303, 3.385, 3.431, 3.437, 3.403, 3.334, 3.238, 3.124, 3.005, 2.889, 2.786, 2.702, 2.641, 2.604, 2.59, 2.597, 2.622, 2.663, 2.716, 2.779, 2.847, 2.917, 2.986, 3.049, 3.1, 3.135, 3.148, 3.134, 3.089, 3.01, 2.898, 2.757, 2.59, 2.408, 2.22, 2.04, 1.881, 1.754, 1.67, 1.633, 1.647, 1.706, 1.804, 1.928, 2.065, 2.201, 2.323, 2.424, 2.497, 2.544, 2.568, 2.578, 2.582, 2.589, 2.607, 2.639, 2.687, 2.746, 2.812, 2.876, 2.93, 2.968, 2.984, 2.977, 2.948, 2.9, 2.84, 2.774, 2.709, 2.653, 2.608, 2.58, 2.568, 2.571, 2.587, 2.614, 2.647, 2.685, 2.725, 2.768, 2.815, 2.868, 2.929, 3.002, 3.087, 3.185, 3.293, 3.408, 3.524, 3.635, 3.733, 3.813, 3.872, 3.909, 3.925, 3.926, 3.918, 3.906, 3.896, 3.892, 3.893, 3.896, 3.892, 3.872, 3.825, 3.739, 3.607, 3.424, 3.192, 2.92, 2.621, 2.314, 2.018, 1.758, 1.552, 1.417, 1.363, 1.394, 1.505, 1.686, 1.92, 2.187, 2.465, 2.731, 2.966, 3.153, 3.281, 3.341, 3.333, 3.256, 3.118, 2.925, 2.69, 2.423, 2.14, 1.854, 1.579, 1.33, 1.117, 0.9523, 0.8413, 0.7885, 0.7945, 0.8567, 0.9699, 1.126, 1.317, 1.531, 1.758, 1.986, 2.204, 2.402, 2.568, 2.693, 2.769, 2.789, 2.751, 2.654, 2.502, 2.301, 2.063, 1.801, 1.529, 1.264, 1.018, 0.8062, 0.6374, 0.5183, 0.4525, 0.4396, 0.4765, 0.5575, 0.6749, 0.8196, 0.9823, 1.154, 1.326, 1.494, 1.654, 1.806, 1.951, 2.096, 2.245, 2.403, 2.574, 2.759, 2.952, 3.147, 3.331, 3.492, 3.615, 3.688, 3.705, 3.66, 3.558, 3.407, 3.222, 3.019, 2.818, 2.635, 2.485, 2.379, 2.322, 2.314, 2.349, 2.418, 2.509, 2.609, 2.706, 2.788, 2.848, 2.881, 2.886, 2.863, 2.816, 2.751, 2.673, 2.588, 2.501, 2.416, 2.334, 2.257, 2.187, 2.125, 2.072, 2.031, 2.007, 2.003, 2.025, 2.077, 2.159, 2.273, 2.414, 2.576, 2.752, 2.932, 3.104, 3.261, 3.396, 3.503, 3.581, 3.63, 3.654, 3.654, 3.633, 3.594, 3.536, 3.457, 3.357, 3.232, 3.082, 2.908, 2.712, 2.503, 2.289, 2.082, 1.895, 1.743, 1.638, 1.588, 1.603, 1.683, 1.828, 2.033, 2.288, 2.579, 2.891, 3.205, 3.501, 3.761, 3.967, 4.105, 4.166, 4.146, 4.049, 3.884, 3.667, 3.418, 3.162, 2.922, 2.72, 2.574, 2.494, 2.485, 2.542, 2.654, 2.804, 2.972, 3.137, 3.279, 3.38, 3.431, 3.427, 3.37, 3.271, 3.147, 3.019, 2.913, 2.854, 2.867, 2.972, 3.183, 3.505, 3.931, 4.445, 5.021, 5.624, 6.215, 6.753, 7.204, 7.538, 7.739, 7.801, 7.731, 7.55, 7.283, 6.963, 6.625, 6.298, 6.009, 5.776, 5.608, 5.506, 5.463, 5.465, 5.495, 5.532, 5.555, 5.548, 5.498, 5.398, 5.248, 5.057, 4.838, 4.609, 4.39, 4.201, 4.056, 3.966, 3.934, 3.955, 4.017, 4.105, 4.197, 4.274, 4.317, 4.313, 4.253, 4.136, 3.968, 3.76, 3.528, 3.289, 3.063, 2.865, 2.707, 2.597, 2.536, 2.523, 2.55, 2.608, 2.686, 2.771, 2.855, 2.928, 2.984, 3.021, 3.036, 3.031, 3.008, 2.968, 2.916, 2.854, 2.786, 2.714, 2.64, 2.566, 2.495, 2.427, 2.365, 2.311, 2.269, 2.24, 2.226, 2.228, 2.247, 2.282, 2.329, 2.384, 2.445, 2.505, 2.561, 2.609, 2.649, 2.679, 2.703, 2.723, 2.744, 2.771, 2.808, 2.859, 2.925, 3.006, 3.099, 3.2, 3.299, 3.39, 3.462, 3.508, 3.519, 3.493, 3.427, 3.323, 3.185, 3.019, 2.831, 2.628, 2.416, 2.198, 1.979, 1.761, 1.545, 1.332, 1.125, 0.9264, 0.7384, 0.5648, 0.4089, 0.2735, 0.1603, 0.06997, 0.001972, -0.04549, -0.07507, -0.09001, -0.09374, -0.08958, -0.08047, -0.06882, -0.05647, -0.04467, -0.03419, -0.02537, -0.01829, -0.01283, -0.008758, -0.005829, -0.003784, -0.002397, -0.001482, -0.0008956, -0.0005286, -0.000305, -0.000172, -9.488e-05, -5.123e-05, -2.713e-05, -1.422e-05, -7.628e-06, -4.697e-06, -4.152e-06, -5.703e-06, -9.914e-06, -1.834e-05, -3.393e-05, -6.175e-05, -0.0001101, -0.000192, -0.0003274, -0.0005461, -0.0008902, -0.001418, -0.002207, -0.003355, -0.004979, -0.007208, -0.01018, -0.014, -0.01875, -0.02441, -0.03086, -0.03777, -0.04463, -0.05067, -0.05484, -0.05584, -0.05213, -0.04199, -0.02361, 0.004872, 0.04526, 0.09923, 0.1683, 0.2537, 0.3565, 0.4771, 0.6156, 0.7714, 0.9427, 1.127, 1.319, 1.515, 1.707, 1.889, 2.053, 2.193, 2.304, 2.386, 2.439, 2.467, 2.477, 2.479, 2.481, 2.492, 2.518, 2.564, 2.628, 2.708, 2.797, 2.888, 2.972, 3.043, 3.096, 3.131, 3.149, 3.157, 3.162, 3.174, 3.202, 3.253, 3.333, 3.446, 3.591, 3.764, 3.962, 4.175, 4.395, 4.611, 4.81, 4.982, 5.114, 5.198, 5.225, 5.193, 5.101, 4.956, 4.768, 4.551, 4.319, 4.09, 3.876, 3.688, 3.533, 3.411, 3.317, 3.247, 3.19, 3.138, 3.086, 3.03, 2.969, 2.907, 2.847, 2.795, 2.757, 2.735, 2.73, 2.74, 2.758, 2.778, 2.792, 2.79, 2.766, 2.716, 2.639, 2.539, 2.422, 2.296, 2.171, 2.06, 1.972, 1.914, 1.891, 1.904, 1.95, 2.024, 2.117, 2.22, 2.32, 2.408, 2.474, 2.512, 2.515, 2.483, 2.417, 2.32, 2.199, 2.062, 1.919, 1.78, 1.651, 1.542, 1.456, 1.396, 1.363, 1.355, 1.368, 1.399, 1.444, 1.499, 1.56, 1.626, 1.693, 1.76, 1.823, 1.88, 1.926, 1.957, 1.97, 1.96, 1.926, 1.867, 1.785, 1.683, 1.566, 1.443, 1.32, 1.209, 1.115, 1.049, 1.013, 1.013, 1.048, 1.113, 1.203, 1.308, 1.416, 1.515, 1.594, 1.643, 1.657, 1.633, 1.572, 1.481, 1.368, 1.243, 1.118, 1.0, 0.9005, 0.8231, 0.771, 0.7437, 0.7386, 0.7511, 0.7758, 0.8069, 0.8394, 0.8692, 0.8938, 0.9123, 0.9249, 0.9329, 0.9383, 0.9428, 0.9478, 0.9536, 0.9597, 0.9647, 0.9662, 0.9615, 0.9478, 0.9229, 0.8853, 0.8344, 0.7711, 0.6969, 0.6146, 0.5274, 0.4389, 0.3526, 0.2715, 0.1983, 0.1348, 0.082, 0.04007, 0.00858, -0.01347, -0.02744, -0.03487, -0.03733, -0.03628, -0.03301, -0.02855, -0.02367, -0.01893, -0.01465, -0.011, -0.008027, -0.005703, -0.003948, -0.002666, -0.001757, -0.00113, -0.0007106, -0.0004365, -0.0002622, -0.000154, -8.843e-05, -4.969e-05, -2.732e-05, -1.47e-05, -7.74e-06, -3.99e-06, -2.013e-06, -9.948e-07, -4.813e-07, -2.28e-07, -1.058e-07, -4.807e-08, -2.139e-08, -9.326e-09, -3.983e-09, -1.666e-09, -6.828e-10, -2.741e-10, -1.078e-10, -4.156e-11, -1.569e-11, -5.807e-12, -2.105e-12, -7.48e-13, -2.604e-13, -8.883e-14, -2.97e-14, -9.729e-15, -3.123e-15, -9.828e-16, -3.03e-16, -9.157e-17, -2.712e-17, -7.872e-18, -2.239e-18, -6.243e-19, -1.706e-19, -4.568e-20, -1.199e-20, -3.085e-21, -7.777e-22, -1.922e-22, -4.655e-23, -1.105e-23, -2.571e-24, -5.863e-25, -1.31e-25, -2.87e-26, -6.163e-27, -1.297e-27, -2.677e-28, -5.503e-29, -1.563e-29, -2.714e-29, -1.255e-28, -6.122e-28, -2.935e-27, -1.379e-26, -6.346e-26, -2.862e-25, -1.265e-24, -5.477e-24, -2.324e-23, -9.661e-23, -3.935e-22, -1.57e-21, -6.14e-21, -2.352e-20, -8.827e-20, -3.246e-19, -1.169e-18, -4.127e-18, -1.427e-17, -4.832e-17, -1.603e-16, -5.212e-16, -1.66e-15, -5.176e-15, -1.581e-14, -4.732e-14, -1.387e-13, -3.983e-13, -1.12e-12, -3.084e-12, -8.319e-12, -2.197e-11, -5.684e-11, -1.44e-10, -3.571e-10, -8.672e-10, -2.062e-09, -4.8e-09, -1.094e-08, -2.441e-08, -5.33e-08, -1.139e-07, -2.383e-07, -4.879e-07, -9.774e-07, -1.916e-06, -3.674e-06, -6.891e-06, -1.264e-05, -2.269e-05, -3.98e-05, -6.827e-05, -0.0001145, -0.0001876, -0.0003004, -0.0004698, -0.0007178, -0.001071, -0.001559, -0.002216, -0.003072, -0.004151, -0.005467, -0.00701, -0.008744, -0.01059, -0.01244, -0.01412, -0.01539, -0.01597, -0.01549, -0.01351, -0.00949, -0.002779, 0.007389, 0.0219, 0.04172, 0.06784, 0.1012, 0.1424, 0.1918, 0.2489, 0.3126, 0.3809, 0.4507, 0.5185, 0.5801, 0.6315, 0.6691, 0.6903, 0.6942, 0.6816, 0.6551, 0.6188, 0.5782, 0.5395, 0.5086, 0.4908, 0.4899, 0.5082, 0.5456, 0.6006, 0.6694, 0.7473, 0.8285, 0.907, 0.9772, 1.034, 1.075, 1.096, 1.099, 1.084, 1.054, 1.012, 0.9627, 0.9094, 0.8558, 0.8045, 0.7577, 0.717, 0.6839, 0.6601, 0.6483, 0.6518, 0.6747, 0.722, 0.7984, 0.908, 1.054, 1.237, 1.456, 1.708, 1.987, 2.285, 2.593, 2.903, 3.204, 3.486, 3.742, 3.965, 4.15, 4.293, 4.397, 4.463, 4.497, 4.508, 4.504, 4.493, 4.483, 4.479, 4.48, 4.486, 4.49, 4.483, 4.457, 4.405, 4.323, 4.211, 4.076, 3.93, 3.787, 3.666, 3.585, 3.562, 3.608, 3.73, 3.925, 4.187, 4.499, 4.841, 5.187, 5.513, 5.793, 6.004, 6.129, 6.158, 6.085, 5.913, 5.651, 5.309, 4.906, 4.458, 3.983, 3.499, 3.023, 2.57, 2.155, 1.79, 1.489, 1.264, 1.128, 1.091, 1.167, 1.364, 1.692, 2.156, 2.758, 3.495, 4.359, 5.333, 6.395, 7.514, 8.649, 9.757, 10.79, 11.7, 12.43, 12.97, 13.27, 13.33, 13.15, 12.77, 12.2, 11.5, 10.72, 9.895, 9.074, 8.291, 7.571, 6.929, 6.372, 5.899, 5.504, 5.181, 4.918, 4.707, 4.537, 4.398, 4.281, 4.178, 4.079, 3.976, 3.864, 3.738, 3.597, 3.441, 3.274, 3.102, 2.933, 2.775, 2.637, 2.526, 2.449, 2.411, 2.413, 2.458, 2.543, 2.667, 2.824, 3.009, 3.215, 3.432, 3.652, 3.863, 4.054, 4.217, 4.344, 4.432, 4.481, 4.495, 4.482, 4.452, 4.416, 4.384, 4.364, 4.359, 4.367, 4.384, 4.4, 4.407, 4.396, 4.363, 4.308, 4.234, 4.154, 4.08, 4.028, 4.012, 4.041, 4.119, 4.245, 4.407, 4.591, 4.776, 4.94, 5.063, 5.126, 5.118, 5.032, 4.869, 4.634, 4.339, 3.999, 3.632, 3.255, 2.885, 2.537, 2.222, 1.952, 1.731, 1.565, 1.453, 1.396, 1.393, 1.444, 1.548, 1.706, 1.918, 2.184, 2.503, 2.871, 3.28, 3.717, 4.162, 4.593, 4.983, 5.306, 5.536, 5.652, 5.642, 5.503, 5.241, 4.873, 4.424, 3.926, 3.413, 2.918, 2.473, 2.102, 1.823, 1.646, 1.575, 1.603, 1.722, 1.917, 2.173, 2.471, 2.796, 3.131, 3.462, 3.776, 4.063, 4.316, 4.528, 4.695, 4.817, 4.895, 4.93, 4.929, 4.895, 4.835, 4.754, 4.658, 4.548, 4.428, 4.297, 4.156, 4.004, 3.841, 3.669, 3.489, 3.306, 3.123, 2.947, 2.781, 2.629, 2.494, 2.374, 2.27, 2.176, 2.091, 2.009, 1.928, 1.846, 1.765, 1.688, 1.619, 1.566, 1.535, 1.533, 1.566, 1.637, 1.745, 1.888, 2.058, 2.246, 2.441, 2.63, 2.801, 2.944, 3.05, 3.116, 3.139, 3.122, 3.068, 2.983, 2.874, 2.748, 2.61, 2.467, 2.324, 2.184, 2.051, 1.929, 1.821, 1.729, 1.656, 1.602, 1.567, 1.549, 1.545, 1.549, 1.555, 1.557, 1.547, 1.52, 1.472, 1.4, 1.305, 1.188, 1.058, 0.9221, 0.7926, 0.6826, 0.6055, 0.5744, 0.6001, 0.69, 0.8468, 1.068, 1.345, 1.665, 2.008, 2.355, 2.682, 2.969, 3.195, 3.346, 3.413, 3.394, 3.291, 3.111, 2.869, 2.577, 2.252, 1.911, 1.569, 1.24, 0.9372, 0.6706, 0.45, 0.2836, 0.1781, 0.1388, 0.1689, 0.2691, 0.4368, 0.6657, 0.9454, 1.262, 1.597, 1.931, 2.245, 2.519, 2.737, 2.888, 2.966, 2.971, 2.909, 2.79, 2.627, 2.434, 2.228, 2.024, 1.833, 1.668, 1.537, 1.447, 1.403, 1.408, 1.46, 1.557, 1.692, 1.856, 2.037, 2.22, 2.391, 2.536, 2.643, 2.704, 2.718, 2.684, 2.612, 2.511, 2.395, 2.28, 2.179, 2.104, 2.063, 2.058, 2.089, 2.147, 2.223, 2.304, 2.379, 2.437, 2.471, 2.48, 2.468, 2.446, 2.429, 2.436, 2.486, 2.599, 2.79, 3.07, 3.441, 3.898, 4.43, 5.017, 5.631, 6.245, 6.827, 7.346, 7.778, 8.101, 8.302, 8.377, 8.328, 8.167, 7.91, 7.58, 7.201, 6.794, 6.383, 5.985, 5.612, 5.272, 4.97, 4.703, 4.47, 4.264, 4.082, 3.918, 3.769, 3.634, 3.51, 3.396, 3.293, 3.198, 3.109, 3.026, 2.946, 2.867, 2.789, 2.712, 2.635, 2.559, 2.486, 2.415, 2.347, 2.28, 2.211, 2.139, 2.059, 1.969, 1.867, 1.751, 1.62, 1.475, 1.32, 1.157, 0.9912, 0.8264, 0.6676, 0.5194, 0.3853, 0.2682, 0.1696, 0.08998, 0.02888, -0.0152, -0.04439, -0.06122, -0.06837, -0.06842, -0.06372, -0.05623, -0.04749, -0.03864, -0.0304, -0.02319, -0.01719, -0.01241, -0.008723, -0.005981, -0.004003, -0.002616, -0.00167, -0.001042, -0.0006359, -0.0003795, -0.0002215, -0.0001265, -7.074e-05, -3.871e-05, -2.074e-05, -1.088e-05, -5.587e-06, -2.81e-06, -1.384e-06, -6.681e-07, -3.158e-07, -1.462e-07, -6.633e-08, -2.948e-08, -1.284e-08, -5.478e-09, -2.29e-09, -9.383e-10, -3.767e-10, -1.482e-10, -5.713e-11, -2.158e-11, -7.992e-12, -2.9e-12, -1.031e-12, -3.594e-13, -1.227e-13, -4.108e-14, -1.348e-14, -4.333e-15, -1.365e-15, -4.217e-16, -1.276e-16, -3.786e-17, -1.101e-17, -3.136e-18, -8.757e-19, -2.397e-19, -6.428e-20, -1.69e-20, -4.354e-21, -1.099e-21, -2.721e-22, -6.599e-23, -1.569e-23, -3.654e-24, -8.344e-25, -1.867e-25, -4.095e-26, -8.801e-27, -1.854e-27, -3.827e-28, -7.744e-29, -1.536e-29, -2.984e-30, -5.684e-31, -1.061e-31, -1.941e-32, -3.48e-33, -6.115e-34, -1.053e-34, -1.777e-35, -2.94e-36, -4.765e-37, -7.571e-38, -1.179e-38, -1.799e-39, -2.69e-40, -3.944e-41, -5.665e-42, -7.975e-43, -1.1e-43, -1.488e-44, -1.972e-45, -2.562e-46, -3.261e-47, -4.068e-48, -4.974e-49, -5.961e-50, -7.001e-51, -8.058e-52, -9.09e-53, -1.005e-53, -1.089e-54, -1.156e-55, -1.204e-56, -1.228e-57, -1.228e-58, -1.203e-59, -1.155e-60, -1.087e-61, -1.003e-62, -9.065e-64, -8.032e-65, -6.975e-66, -5.936e-67, -4.952e-68, -4.048e-69, -3.244e-70, -2.547e-71, -1.961e-72, -1.479e-73, -1.093e-74, -7.923e-76, -5.628e-77, -3.929e-78, -2.793e-79, -2.999e-80, -1.33e-80, -1.222e-80, -1.216e-80, -1.216e-80, -1.217e-80, -1.218e-80, -1.22e-80, -1.221e-80, -1.222e-80, -1.223e-80, -1.224e-80, -1.225e-80, -1.226e-80, -1.227e-80, -1.228e-80, -1.229e-80, -1.23e-80, -1.231e-80, -1.232e-80, -1.233e-80, -1.234e-80, -1.235e-80, -1.236e-80, -1.237e-80, -1.238e-80, -1.239e-80, -1.24e-80, -1.241e-80, -1.242e-80, -1.243e-80, -1.244e-80, -1.246e-80, -1.247e-80, -1.248e-80, -1.249e-80, -1.259e-80, -1.39e-80, -3.364e-80, -3.263e-79, -4.582e-78, -6.523e-77, -9.124e-76, -1.251e-74, -1.681e-73, -2.213e-72, -2.857e-71, -3.614e-70, -4.48e-69, -5.444e-68, -6.482e-67, -7.566e-66, -8.654e-65, -9.701e-64, -1.066e-62, -1.148e-61, -1.211e-60, -1.253e-59, -1.27e-58, -1.261e-57, -1.228e-56, -1.172e-55, -1.096e-54, -1.004e-53, -9.019e-53, -7.938e-52, -6.848e-51, -5.789e-50, -4.796e-49, -3.894e-48, -3.099e-47, -2.417e-46, -1.847e-45, -1.383e-44, -1.015e-43, -7.302e-43, -5.147e-42, -3.556e-41, -2.407e-40, -1.597e-39, -1.038e-38, -6.614e-38, -4.129e-37, -2.526e-36, -1.515e-35, -8.899e-35, -5.123e-34, -2.89e-33, -1.598e-32, -8.657e-32, -4.596e-31, -2.391e-30, -1.219e-29, -6.087e-29, -2.979e-28, -1.429e-27, -6.715e-27, -3.092e-26, -1.395e-25, -6.167e-25, -2.672e-24, -1.134e-23, -4.715e-23, -1.921e-22, -7.67e-22, -3e-21, -1.15e-20, -4.316e-20, -1.588e-19, -5.721e-19, -2.02e-18, -6.986e-18, -2.367e-17, -7.857e-17, -2.555e-16, -8.138e-16, -2.539e-15, -7.761e-15, -2.324e-14, -6.814e-14, -1.957e-13, -5.505e-13, -1.517e-12, -4.093e-12, -1.082e-11, -2.799e-11, -7.094e-11, -1.761e-10, -4.278e-10, -1.018e-09, -2.371e-09, -5.408e-09, -1.207e-08, -2.639e-08, -5.647e-08, -1.182e-07, -2.424e-07, -4.861e-07, -9.542e-07, -1.833e-06, -3.444e-06, -6.332e-06, -1.139e-05, -2.003e-05, -3.447e-05, -5.8e-05, -9.542e-05, -0.0001535, -0.0002414, -0.000371, -0.0005574, -0.0008181, -0.001173, -0.001643, -0.002246, -0.002998, -0.003901, -0.004946, -0.006102, -0.007308, -0.00847, -0.009448, -0.01005, -0.01002, -0.009034, -0.006701, -0.002549, 0.003953, 0.01337, 0.02628, 0.04317, 0.06439, 0.09004, 0.1199, 0.1532, 0.189, 0.2255, 0.2607, 0.2925, 0.3186, 0.3371, 0.3466, 0.3465, 0.3372, 0.3201, 0.2975, 0.2724, 0.2482, 0.2283, 0.2157, 0.2126, 0.2202, 0.2388, 0.2675, 0.3044, 0.3473, 0.3933, 0.4397, 0.4837, 0.5234, 0.5569, 0.5832, 0.6017, 0.6122, 0.615, 0.6103, 0.5987, 0.5809, 0.5577, 0.5304, 0.5003, 0.4696, 0.4407, 0.4167, 0.401, 0.3971, 0.4081, 0.4365, 0.4832, 0.5478, 0.6278, 0.7189, 0.8155, 0.9109, 0.9983, 1.072, 1.126, 1.159, 1.169, 1.159, 1.132, 1.091, 1.043, 0.9923, 0.9418, 0.8943, 0.8509, 0.8115, 0.7753, 0.7408, 0.7073, 0.6745, 0.6434, 0.6159, 0.5952, 0.5847, 0.5882, 0.6087, 0.6483, 0.7074, 0.7852, 0.879, 0.9851, 1.099, 1.216, 1.332, 1.443, 1.545, 1.636, 1.715, 1.777, 1.822, 1.847, 1.85, 1.828, 1.782, 1.71, 1.617, 1.507, 1.387, 1.267, 1.155, 1.064, 1.001, 0.9751, 0.9904, 1.049, 1.148, 1.282, 1.443, 1.62, 1.801, 1.973, 2.125, 2.247, 2.331, 2.372, 2.37, 2.328, 2.25, 2.144, 2.021, 1.89, 1.762, 1.647, 1.554, 1.488, 1.455, 1.456, 1.49, 1.553, 1.641, 1.747, 1.863, 1.981, 2.096, 2.202, 2.295, 2.373, 2.437, 2.487, 2.524, 2.549, 2.563, 2.566, 2.556, 2.531, 2.489, 2.429, 2.351, 2.256, 2.145, 2.021, 1.89, 1.755, 1.621, 1.492, 1.374, 1.27, 1.183, 1.116, 1.073, 1.057, 1.07, 1.115, 1.195, 1.312, 1.465, 1.653, 1.872, 2.113, 2.368, 2.623, 2.863, 3.074, 3.24, 3.35, 3.397, 3.379, 3.299, 3.168, 2.999, 2.808, 2.613, 2.429, 2.269, 2.141, 2.046, 1.983, 1.947, 1.929, 1.922, 1.918, 1.915, 1.911, 1.909, 1.915, 1.935, 1.976, 2.043, 2.14, 2.264, 2.413, 2.578, 2.751, 2.92, 3.075, 3.206, 3.307, 3.374, 3.404, 3.399, 3.362, 3.298, 3.211, 3.108, 2.995, 2.878, 2.76, 2.646, 2.537, 2.436, 2.34, 2.247, 2.154, 2.056, 1.948, 1.829, 1.695, 1.548, 1.392, 1.232, 1.079, 0.943, 0.8366, 0.7714, 0.7573, 0.8014, 0.9067, 1.071, 1.289, 1.549, 1.835, 2.13, 2.415, 2.671, 2.88, 3.029, 3.107, 3.108, 3.032, 2.883, 2.671, 2.407, 2.109, 1.793, 1.477, 1.18, 0.9186, 0.7056, 0.5517, 0.4634, 0.443, 0.4883, 0.5931, 0.748, 0.9407, 1.157, 1.383, 1.605, 1.81, 1.987, 2.129, 2.232, 2.292, 2.31, 2.29, 2.237, 2.157, 2.058, 1.949, 1.84, 1.74, 1.66, 1.607, 1.588, 1.608, 1.666, 1.761, 1.886, 2.03, 2.181, 2.324, 2.447, 2.538, 2.588, 2.595, 2.56, 2.49, 2.396, 2.291, 2.191, 2.108, 2.056, 2.045, 2.079, 2.161, 2.289, 2.456, 2.656, 2.876, 3.106, 3.332, 3.541, 3.72, 3.859, 3.947, 3.979, 3.951, 3.865, 3.722, 3.532, 3.303, 3.047, 2.776, 2.503, 2.238, 1.99, 1.765, 1.566, 1.395, 1.25, 1.126, 1.02, 0.9264, 0.8412, 0.7613, 0.6856, 0.6145, 0.5503, 0.4965, 0.4573, 0.4371, 0.4395, 0.4672, 0.5212, 0.6013, 0.7055, 0.831, 0.9743, 1.131, 1.298, 1.47, 1.643, 1.815, 1.98, 2.134, 2.275, 2.397, 2.498, 2.577, 2.632, 2.666, 2.68, 2.678, 2.665, 2.644, 2.62, 2.594, 2.567, 2.537, 2.5, 2.453, 2.39, 2.306, 2.198, 2.064, 1.902, 1.715, 1.509, 1.289, 1.063, 0.8417, 0.633, 0.4455, 0.2863, 0.1607, 0.07235, 0.02281, 0.01208, 0.03882, 0.1007, 0.1947, 0.3173, 0.4649, 0.6332, 0.8176, 1.013, 1.212, 1.408, 1.592, 1.755, 1.887, 1.979, 2.025, 2.019, 1.959, 1.848, 1.692, 1.499, 1.282, 1.054, 0.8306, 0.6239, 0.4457, 0.305, 0.2073, 0.1551, 0.1473, 0.1803, 0.248, 0.3428, 0.4558, 0.5781, 0.7009, 0.816, 0.9169, 0.9987, 1.059, 1.096, 1.112, 1.111, 1.097, 1.077, 1.056, 1.041, 1.035, 1.04, 1.055, 1.077, 1.102, 1.123, 1.133, 1.126, 1.098, 1.049, 0.9806, 0.8971, 0.8065, 0.7183, 0.6422, 0.5873, 0.5611, 0.5681, 0.6098, 0.6842, 0.7866, 0.9097, 1.045, 1.182, 1.311, 1.425, 1.515, 1.576, 1.606, 1.602, 1.566, 1.501, 1.411, 1.301, 1.179, 1.052, 0.9281, 0.8141, 0.7175, 0.6443, 0.5996, 0.5866, 0.6068, 0.6597, 0.7425, 0.8505, 0.977, 1.114, 1.254, 1.387, 1.508, 1.612, 1.697, 1.765, 1.822, 1.874, 1.932, 2.003, 2.096, 2.215, 2.359, 2.526, 2.706, 2.89, 3.063, 3.213, 3.33, 3.405, 3.435, 3.42, 3.363, 3.271, 3.152, 3.015, 2.867, 2.714, 2.561, 2.41, 2.264, 2.125, 1.997, 1.883, 1.791, 1.726, 1.698, 1.715, 1.78, 1.898, 2.066, 2.278, 2.522, 2.782, 3.042, 3.282, 3.485, 3.636, 3.726, 3.751, 3.716, 3.629, 3.504, 3.359, 3.211, 3.077, 2.971, 2.901, 2.871, 2.878, 2.915, 2.972, 3.034, 3.089, 3.123, 3.127, 3.092, 3.016, 2.898, 2.74, 2.548, 2.327, 2.085, 1.831, 1.57, 1.312, 1.062, 0.8253, 0.6081, 0.4144, 0.2477, 0.1108, 0.006002, -0.06491, -0.1006, -0.09997, -0.06241, 0.01236, 0.124, 0.2713, 0.4518, 0.6617, 0.8953, 1.145, 1.403, 1.659, 1.902, 2.123, 2.312, 2.463, 2.572, 2.639, 2.665, 2.657, 2.621, 2.567, 2.503, 2.438, 2.379, 2.33, 2.294, 2.272, 2.262, 2.261, 2.265, 2.272, 2.277, 2.278, 2.275, 2.268, 2.259, 2.254, 2.256, 2.273, 2.308, 2.365, 2.447, 2.55, 2.67, 2.796, 2.918, 3.02, 3.09, 3.114, 3.083, 2.99, 2.835, 2.622, 2.361, 2.065, 1.749, 1.428, 1.117, 0.8307, 0.5771, 0.3629, 0.1904, 0.0588, -0.0352, -0.09684, -0.1323, -0.1481, -0.1501, -0.1436, -0.1326, -0.1199, -0.1072, -0.09487, -0.08233, -0.06827, -0.05085, -0.02798, 0.002317, 0.04163, 0.09078, 0.1496, 0.2169, 0.2902, 0.3662, 0.4408, 0.51, 0.57, 0.6185, 0.6543, 0.6783, 0.6932, 0.7033, 0.7141, 0.7315, 0.7609, 0.8065, 0.8709, 0.954, 1.054, 1.165, 1.282, 1.396, 1.5, 1.586, 1.647, 1.68, 1.682, 1.653, 1.598, 1.52, 1.427, 1.324, 1.22, 1.118, 1.025, 0.9407, 0.8674, 0.8047, 0.7516, 0.7071, 0.6703, 0.6411, 0.6195, 0.606, 0.6005, 0.6025, 0.6107, 0.6227, 0.6353, 0.6453, 0.6494, 0.6457, 0.6332, 0.613, 0.5875, 0.5605, 0.5366, 0.5201, 0.5145, 0.522, 0.5427, 0.575, 0.6156, 0.66, 0.7032, 0.7403, 0.7672, 0.7811, 0.7804, 0.7648, 0.7354, 0.6939, 0.6427, 0.5844, 0.5214, 0.4559, 0.3902, 0.326, 0.2647, 0.2078, 0.1564, 0.1111, 0.07267, 0.04117, 0.01652, -0.001692, -0.01414, -0.0217, -0.02531, -0.02596, -0.02457, -0.02192, -0.01866, -0.01528, -0.0121, -0.009342, -0.007099, -0.005414, -0.004286, -0.003704, -0.00366, -0.004163, -0.005239, -0.006925, -0.009256, -0.01224, -0.01585, -0.01994, -0.02425, -0.02836, -0.03164, -0.03323, -0.03209, -0.02693, -0.01639, 0.0009908, 0.02657, 0.06153, 0.1067, 0.1624, 0.2283, 0.3034, 0.386, 0.4734, 0.5624, 0.6491, 0.7291, 0.7981, 0.8519, 0.887, 0.9007, 0.8915, 0.8597, 0.8066, 0.7353, 0.6499, 0.5553, 0.4566, 0.359, 0.2668, 0.1835, 0.1114, 0.05165, 0.004201, -0.03173, -0.05747, -0.07452, -0.08424, -0.08756, -0.08477, -0.07553, -0.05886, -0.03336, 0.002578, 0.05037, 0.1109, 0.1843, 0.2695, 0.3642, 0.4648, 0.5667, 0.6648, 0.7534, 0.8273, 0.8818, 0.9138, 0.9212, 0.9039, 0.8631, 0.8017, 0.7234, 0.6327, 0.5344, 0.4332, 0.3337, 0.2397, 0.1547, 0.08163, 0.02285, -0.01946, -0.04335, -0.04704, -0.02897, 0.01207, 0.07668, 0.1646, 0.2741, 0.4023, 0.5445, 0.6943, 0.8441, 0.9854, 1.109, 1.208, 1.275, 1.305, 1.297, 1.25, 1.169, 1.06, 0.9299, 0.7873, 0.641, 0.4988, 0.3674, 0.2516, 0.1545, 0.07729, 0.01941, -0.02084, -0.04602, -0.05912, -0.06318, -0.06104, -0.05513, -0.04739, -0.03928, -0.03178, -0.02553, -0.02088, -0.01796, -0.01681, -0.01737, -0.01948, -0.0229, -0.02724, -0.03193, -0.03611, -0.03864, -0.03803, -0.03254, -0.02023, 0.0008609, 0.03244, 0.07569, 0.131, 0.1977, 0.2738, 0.356, 0.44, 0.5206, 0.5922, 0.6495, 0.6879, 0.7044, 0.6975, 0.6677, 0.6174, 0.5504, 0.4718, 0.3869, 0.301, 0.2188, 0.1439, 0.07879, 0.02484, -0.01761, -0.04891, -0.06969, -0.08063, -0.08208, -0.07399, -0.05585, -0.02682, 0.01406, 0.06754, 0.1338, 0.2123, 0.3012, 0.3977, 0.4979, 0.5971, 0.69, 0.7715, 0.8367, 0.882, 0.9049, 0.9043, 0.8808, 0.8364, 0.7742, 0.6982, 0.6129, 0.5227, 0.4319, 0.3442, 0.2628, 0.1897, 0.1265, 0.07369, 0.03123, -0.001444, -0.02522, -0.04114, -0.05019, -0.05319, -0.05069, -0.04294, -0.02991, -0.01145, 0.01264, 0.04237, 0.07739, 0.1169, 0.1594, 0.2031, 0.2454, 0.2838, 0.3156, 0.3384, 0.3505, 0.3509, 0.3396, 0.3176, 0.2866, 0.2489, 0.2072, 0.1641, 0.1221, 0.08303, 0.04831, 0.01865, -0.005761, -0.0251, -0.03974, -0.05001, -0.05602, -0.05751, -0.05375, -0.04361, -0.02563, 0.001723, 0.03982, 0.08947, 0.1507, 0.2223, 0.302, 0.3861, 0.4699, 0.548, 0.6151, 0.666, 0.6966, 0.7046, 0.6891, 0.6516, 0.5949, 0.5235, 0.4427, 0.358, 0.2747, 0.1973, 0.1292, 0.07248, 0.02814, -0.003917, -0.02454, -0.0351, -0.0372, -0.03248, -0.02249, -0.008625, 0.007888, 0.02594, 0.0445, 0.06259, 0.07925, 0.09359, 0.1048, 0.1124, 0.1158, 0.115, 0.1102, 0.102, 0.09092, 0.07801, 0.06416, 0.05029, 0.0372, 0.0255, 0.0156, 0.007694, 0.001772, -0.002319, -0.004839, -0.006102, -0.006431, -0.006129, -0.00545, -0.004594, -0.003706, -0.002877, -0.002158, -0.001568, -0.001106, -0.000758, -0.0005059, -0.0003289, -0.0002085, -0.000129, -7.784e-05],
                          list(map(lambda x: x.value, dos.scalars)))
        
        # Delete the data
        delete_example('VS2.scf')
        
    def test_pw_vdw(self):
        # Parse the results
        parser = self.get_parser('pw_vdw')
        
        # Test the settings
        self.assertEquals('PWSCF', parser.get_name())

        strc = parser.get_output_structure()
        self.assertEquals(2.46596598034, strc.cell[0][0])
        self.assertEquals(2.1355881881239482, strc.cell[1][1])
        self.assertEquals(6.4115115488840004, strc.cell[2][2])
        self.assertEquals(['C', 'C', 'C', 'C'], strc.get_chemical_symbols())
        self.assertEquals('C4', parser.get_composition())
        
        cutoff = parser.get_cutoff_energy()
        self.assertEquals(45.0, cutoff.scalars[0].value)
        self.assertEquals('Ry', cutoff.units)
       
        self.assertTrue(parser.is_converged().scalars[0].value)

        energy = parser.get_total_energy()
        self.assertEquals(-44.61813252, energy.scalars[0].value)
        self.assertEquals('Ry', energy.units)

        self.assertEquals(None, parser.uses_SOC())
        self.assertEquals(None, parser.is_relaxed())
        self.assertEquals('SLA PW PBX PBC', parser.get_xc_functional().scalars[0].value)
        self.assertEquals(['C.pbe-mt_gipaw.UPF'], list(map(lambda x: x.value, parser.get_pp_name().scalars)))
        self.assertEquals(4, parser.get_KPPRA().scalars[0].value)
        self.assertEquals('6.0', parser.get_version_number())
        self.assertEquals(None, parser.get_U_settings())
        self.assertEquals('Tkatchenko-Scheffler', parser.get_vdW_settings().scalars[0].value)

        pressure = parser.get_pressure()
        self.assertEquals(188.77, pressure.scalars[0].value)
        self.assertEquals('kbar', pressure.units)

        stresses = parser.get_stresses()
        self.assertEquals([[185.91, -1.88, 0.0], [-1.88, 183.74, 0.0], [0.0, 0.0, 196.65]],
                          list(map(lambda x: list(map(lambda y: y.value, x)), stresses.matrices[0])))
        self.assertEquals('kbar', stresses.units)

        self.assertEquals(None, parser.get_band_gap())

        # Delete the data
        delete_example('pw_vdw')

    def test_pw_ldaU(self):
        # Parse the results
        parser = self.get_parser('pw_lda+U')
        
        # Test the settings
        self.assertEquals('PWSCF', parser.get_name())
        strc = parser.get_output_structure()
        self.assertEquals(2.1669808346549999, strc.cell[0][0])
        self.assertEquals(4.3339616693099998, strc.cell[1][1])
        self.assertEquals(['O', 'O', 'Fe', 'Fe'], strc.get_chemical_symbols())
        self.assertEquals('Fe2O2', parser.get_composition())
        
        cutoff = parser.get_cutoff_energy()
        self.assertEquals(30.0, cutoff.scalars[0].value)
        self.assertEquals('Ry', cutoff.units)
        
        self.assertTrue(parser.is_converged().scalars[0].value)

        energy = parser.get_total_energy()
        self.assertEquals(-174.47156021, energy.scalars[0].value)
        self.assertEquals('Ry', energy.units)

        self.assertEquals(None, parser.uses_SOC())
        self.assertEquals(None, parser.is_relaxed())
        self.assertEquals('SLA PZ NOGX NOGC', parser.get_xc_functional().scalars[0].value)
        self.assertEquals(['O.pz-rrkjus.UPF', 'Fe.pz-nd-rrkjus.UPF', 'Fe.pz-nd-rrkjus.UPF'], list(map(lambda x: x.value, parser.get_pp_name().scalars)))
        self.assertEquals(32, parser.get_KPPRA().scalars[0].value)
        self.assertEquals('6.0', parser.get_version_number())

        U_settings = parser.get_U_settings()
        self.assertEquals('Simplified', U_settings.Type)
        self.assertEquals({'Fe2': {'J': 0.0, 'U': 4.3, 'L': 2.0}, 'Fe1': {'J': 0.0, 'U': 4.3, 'L': 2.0}}, U_settings.Values)

        self.assertEquals(None, parser.get_vdW_settings())
        self.assertEquals(None, parser.get_pressure())
        self.assertEquals(None, parser.get_stresses())
        self.assertEquals(None, parser.get_band_gap())

        # Delete the data
        delete_example('pw_lda+U')
        
if __name__ == '__main__':
    unittest.main()
